@@ -21,20 +21,29 @@
 #include "config.h"
 #ifndef HAVE_STRNDUP
 
+
 #include <stdlib.h>
 #include <string.h>
+
+extern char *strndup(const char *s, size_t n);
+
 char *
 strndup(const char *s, size_t n)
 {
 	const size_t len = strlen(s);
+	char *new_s;
 	if(len <= n)
 		return strdup(s);
-	char *const new_s = malloc(n+1);
+	new_s = malloc(n+1);
 	if(new_s == NULL)
 		return NULL;
 	memcpy(new_s, s, n);
 	new_s[n] = '\0';
 	return new_s;
 }
-
+#else
+/* XLC needs at least one method in source file even static to compile */
+#ifdef __xlc__
+static void dummy() {}
+#endif
 #endif /* #ifndef HAVE_STRNDUP */
