@@ -73,6 +73,7 @@
 #include "cryprov.h"
 #include "parserif.h"
 #include "janitor.h"
+#include "rsconf.h"
 
 MODULE_TYPE_OUTPUT
 MODULE_TYPE_NOKEEP
@@ -457,14 +458,14 @@ finalize_it:
  * as the index of the to-be-deleted entry. This index may
  * point to an unallocated entry, in whcih case the
  * function immediately returns. Parameter bFreeEntry is 1
- * if the entry should be d_free()ed and 0 if not.
+ * if the entry should be free()ed and 0 if not.
  */
 static rsRetVal
 dynaFileDelCacheEntry(instanceData *__restrict__ const pData, const int iEntry, const int bFreeEntry)
 {
 	dynaFileCacheEntry **pCache = pData->dynCache;
 	DEFiRet;
-	ASSERT(pCache != NULL);
+	assert(pCache != NULL);
 
 	if(pCache[iEntry] == NULL)
 		FINALIZE;
@@ -473,7 +474,7 @@ dynaFileDelCacheEntry(instanceData *__restrict__ const pData, const int iEntry,
 		pCache[iEntry]->pName == NULL ? UCHAR_CONSTANT("[OPEN FAILED]") : pCache[iEntry]->pName);
 
 	if(pCache[iEntry]->pName != NULL) {
-		d_free(pCache[iEntry]->pName);
+		free(pCache[iEntry]->pName);
 		pCache[iEntry]->pName = NULL;
 	}
 
@@ -486,7 +487,7 @@ dynaFileDelCacheEntry(instanceData *__restrict__ const pData, const int iEntry,
 	}
 
 	if(bFreeEntry) {
-		d_free(pCache[iEntry]);
+		free(pCache[iEntry]);
 		pCache[iEntry] = NULL;
 	}
 
@@ -503,14 +504,12 @@ static void
 dynaFileFreeCacheEntries(instanceData *__restrict__ const pData)
 {
 	register uint i;
-	ASSERT(pData != NULL);
+	assert(pData != NULL);
 
-	BEGINfunc;
 	for(i = 0 ; i < pData->iCurrCacheSize ; ++i) {
 		dynaFileDelCacheEntry(pData, i, 1);
 	}
 	pData->iCurrElt = -1; /* invalidate current element */
-	ENDfunc;
 }
 
 
@@ -518,13 +517,11 @@ dynaFileFreeCacheEntries(instanceData *__restrict__ const pData)
  */
 static void dynaFileFreeCache(instanceData *__restrict__ const pData)
 {
-	ASSERT(pData != NULL);
+	assert(pData != NULL);
 
-	BEGINfunc;
 	dynaFileFreeCacheEntries(pData);
 	if(pData->dynCache != NULL)
-		d_free(pData->dynCache);
-	ENDfunc;
+		free(pData->dynCache);
 }
 
 
@@ -654,7 +651,7 @@ prepareFile(instanceData *__restrict__ const pData, const uchar *__restrict__ co
 
 	if(pData->useSigprov)
 		sigprovPrepare(pData, szNameBuf);
-	
+
 finalize_it:
 	if(iRet != RS_RET_OK) {
 		if(pData->pStrm != NULL) {
@@ -684,9 +681,9 @@ fsCheck(instanceData *__restrict__ const pData, const uchar *__restrict__ const
 	}
 
 	/* check if we have space available for all buffers to be flushed and for
-	 * a maximum lenght message, perhaps current msg size would be enough */
+	 * a maximum length message, perhaps current msg size would be enough */
 	if (stat.f_bsize * stat.f_bavail <
-		pData->iIOBufSize * pData->iDynaFileCacheSize + (uint)(glbl.GetMaxLine()))
+		pData->iIOBufSize * pData->iDynaFileCacheSize + (uint)(glbl.GetMaxLine(runModConf->pConf)))
 		{
 			iRet = RS_RET_FS_ERR;
 			LogError(0, iRet, "too few available blocks in %s", path);
@@ -737,8 +734,8 @@ prepareDynFile(instanceData *__restrict__ const pData, const uchar *__restrict__
 	dynaFileCacheEntry **pCache;
 	DEFiRet;
 
-	ASSERT(pData != NULL);
-	ASSERT(newFileName != NULL);
+	assert(pData != NULL);
+	assert(newFileName != NULL);
 
 	pCache = pData->dynCache;
 
@@ -859,8 +856,8 @@ static  rsRetVal
 doWrite(instanceData *__restrict__ const pData, uchar *__restrict__ const pszBuf, const int lenBuf)
 {
 	DEFiRet;
-	ASSERT(pData != NULL);
-	ASSERT(pszBuf != NULL);
+	assert(pData != NULL);
+	assert(pszBuf != NULL);
 
 	DBGPRINTF("omfile: write to stream, pData->pStrm %p, lenBuf %d, strt data %.128s\n",
 		  pData->pStrm, lenBuf, pszBuf);
@@ -1006,7 +1003,7 @@ janitorChkDynaFiles(instanceData *__restrict__ const pData)
 				pData->iCurrElt = -1; /* no longer available! */
 			}
 		} else {
-			pCache[i]->nInactive += janitorInterval;
+			pCache[i]->nInactive += runModConf->pConf->globals.janitorInterval;
 		}
 	}
 }
@@ -1027,7 +1024,7 @@ janitorCB(void *pUsr)
 				STATSCOUNTER_INC(pData->ctrCloseTimeouts, pData->mutCtrCloseTimeouts);
 				closeFile(pData);
 			} else {
-				pData->nInactive += janitorInterval;
+				pData->nInactive += runModConf->pConf->globals.janitorInterval;
 			}
 		}
 	}
