@@ -46,6 +46,7 @@ enum cnfobjType {
 	CNFOBJ_PARSER,
 	CNFOBJ_TIMEZONE,
 	CNFOBJ_DYN_STATS,
+	CNFOBJ_PERCTILE_STATS,
 	CNFOBJ_INVALID = 0
 };
 
@@ -97,13 +98,13 @@ struct nvlst {
  * be the sole foundation for the AST.
  *
  * nodetypes (list not yet complete)
+ * A - (string) array
  * F - function
  * N - number
  * P - fparamlst
  * R - rule
  * S - string
  * V - var
- * A - (string) array
  * ... plus the S_* #define's below:
  */
 #define S_STOP 4000
@@ -118,6 +119,7 @@ struct nvlst {
 #define S_FOREACH 4009
 #define S_RELOAD_LOOKUP_TABLE 4010
 #define S_CALL_INDIRECT 4011
+#define S_FUNC_EXISTS 4012 /* special case function which must get varname only */
 
 enum cnfFiltType { CNFFILT_NONE, CNFFILT_PRI, CNFFILT_PROP, CNFFILT_SCRIPT };
 const char* cnfFiltType2str(const enum cnfFiltType filttype);
@@ -242,6 +244,7 @@ enum cnffuncid {
 	CNFFUNC_FORMAT_TIME,
 	CNFFUNC_PARSE_TIME,
 	CNFFUNC_PARSE_JSON,
+	CNFFUNC_GET_PROPERTY,
 	CNFFUNC_PREVIOUS_ACTION_SUSPENDED,
 	CNFFUNC_SCRIPT_ERROR,
 	CNFFUNC_HTTP_REQUEST,
@@ -262,6 +265,12 @@ struct cnffunc {
 } __attribute__((aligned (8)));
 
 
+struct cnffuncexists {
+	unsigned nodetype;
+	const char *varname;
+	msgPropDescr_t prop;
+} __attribute__((aligned (8)));
+
 struct scriptFunct {
 	const char *fname;
 	unsigned short minParams;
@@ -340,6 +349,7 @@ void nvlstDestruct(struct nvlst *lst);
 void nvlstPrint(struct nvlst *lst);
 void nvlstChkUnused(struct nvlst *lst);
 struct nvlst* nvlstFindName(struct nvlst *lst, es_str_t *name);
+int nvlstChkDisabled(struct nvlst *lst);
 struct cnfobj* cnfobjNew(enum cnfobjType objType, struct nvlst *lst);
 void cnfobjDestruct(struct cnfobj *o);
 void cnfobjPrint(struct cnfobj *o);
@@ -353,6 +363,7 @@ struct cnfnumval* cnfnumvalNew(long long val);
 struct cnfstringval* cnfstringvalNew(es_str_t *estr);
 struct cnfvar* cnfvarNew(char *name);
 struct cnffunc * cnffuncNew(es_str_t *fname, struct cnffparamlst* paramlst);
+struct cnffuncexists * cnffuncexistsNew(const char *varname);
 struct cnffparamlst * cnffparamlstNew(struct cnfexpr *expr, struct cnffparamlst *next);
 int cnfDoInclude(const char *name, const int optional);
 int cnfparamGetIdx(struct cnfparamblk *params, const char *name);
