@@ -23,7 +23,6 @@
  * limitations under the License.
  */
 #include "config.h"
-#include "rsyslog.h"
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdlib.h>
@@ -34,6 +33,8 @@
 #include <pthread.h>
 #include <sys/uio.h>
 #include <librdkafka/rdkafka.h>
+
+#include "rsyslog.h"
 #include "conf.h"
 #include "syslogd-types.h"
 #include "srUtils.h"
@@ -319,7 +320,6 @@ static rsRetVal ATTR_NONNULL()
 checkInstance(instanceConf_t *const inst)
 {
 	DEFiRet;
-	int nBrokers;
 	char kafkaErrMsg[1024];
 
 	/* main kafka conf */
@@ -430,7 +430,7 @@ checkInstance(instanceConf_t *const inst)
 	#endif
 
 	DBGPRINTF("imkafka: setting brokers: '%s'\n", inst->brokers);
-	if((nBrokers = rd_kafka_brokers_add(inst->rk, (char*)inst->brokers)) == 0) {
+	if(rd_kafka_brokers_add(inst->rk, (char*)inst->brokers) == 0) {
 		if(inst->bReportErrs) {
 			LogError(0, RS_RET_KAFKA_NO_VALID_BROKERS,
 				"imkafka: no valid brokers specified: %s", inst->brokers);
