@@ -91,6 +91,12 @@ static int n_tcpsrv = 0;
 
 static permittedPeers_t *pPermPeersRoot = NULL;
 
+/* default number of workes to configure. We choose 2, as this is probably good for
+ * many installations. High-Volume ones may need much higher number!
+ */
+#define DEFAULT_NUMWRKR 2
+#define DEFAULT_STARVATIONMAXREADS 500
+
 #define FRAMING_UNSET -1
 
 /* config settings */
@@ -123,6 +129,7 @@ static struct configSettings_s {
 struct instanceConf_s {
 	int iTCPSessMax;
 	int iTCPLstnMax;
+	unsigned numWrkr;
 	tcpLstnParams_t *cnf_params;	/**< listener config parameters */
 	uchar *pszBindRuleset;		/* name of ruleset to bind to */
 	ruleset_t *pBindRuleset;	/* ruleset to bind listener to (use system default if unspecified) */
@@ -157,6 +164,7 @@ struct instanceConf_s {
 	int iKeepAliveIntvl;
 	int iKeepAliveProbes;
 	int iKeepAliveTime;
+	unsigned starvationMaxReads;
 	struct instanceConf_s *next;
 };
 
@@ -166,6 +174,7 @@ struct modConfData_s {
 	instanceConf_t *root, *tail;
 	int iTCPSessMax; /* max number of sessions */
 	int iTCPLstnMax; /* max number of sessions */
+	unsigned numWrkr;
 	int iStrmDrvrMode; /* mode for stream driver, driver-dependent (0 mostly means plain tcp) */
 	int iStrmDrvrExtendedCertCheck; /* verify also purpose OID in certificate extended field */
 	int iStrmDrvrSANPreference; /* ignore CN when any SAN set */
@@ -193,6 +202,7 @@ struct modConfData_s {
 	permittedPeers_t *pPermPeersRoot;
 	sbool configSetViaV2Method;
 	sbool bPreserveCase; /* preserve case of fromhost; true by default */
+	unsigned starvationMaxReads;
 };
 
 static modConfData_t *loadModConf = NULL;/* modConf ptr to use for the current load process */
@@ -211,6 +221,8 @@ static struct cnfparamdescr modpdescr[] = {
 	{ "maxsessions", eCmdHdlrPositiveInt, 0 },
 	{ "maxlistners", eCmdHdlrPositiveInt, 0 },
 	{ "maxlisteners", eCmdHdlrPositiveInt, 0 },
+	{ "workerthreads", eCmdHdlrPositiveInt, 0 },
+	{ "starvationprotection.maxreads", eCmdHdlrNonNegInt, 0 },
 	{ "streamdriver.mode", eCmdHdlrNonNegInt, 0 },
 	{ "streamdriver.authmode", eCmdHdlrString, 0 },
 	{ "streamdriver.permitexpiredcerts", eCmdHdlrString, 0 },
@@ -241,6 +253,7 @@ static struct cnfparamdescr inppdescr[] = {
 	{ "port", eCmdHdlrString, CNFPARAM_REQUIRED }, /* legacy: InputTCPServerRun */
 	{ "maxsessions", eCmdHdlrPositiveInt, 0 },
 	{ "maxlisteners", eCmdHdlrPositiveInt, 0 },
+	{ "workerthreads", eCmdHdlrPositiveInt, 0 },
 	{ "flowcontrol", eCmdHdlrBinary, 0 },
 	{ "disablelfdelimiter", eCmdHdlrBinary, 0 },
 	{ "discardtruncatedmsg", eCmdHdlrBinary, 0 },
@@ -254,6 +267,7 @@ static struct cnfparamdescr inppdescr[] = {
 	{ "name", eCmdHdlrString, 0 },
 	{ "defaulttz", eCmdHdlrString, 0 },
 	{ "ruleset", eCmdHdlrString, 0 },
+	{ "starvationprotection.maxreads", eCmdHdlrNonNegInt, 0 },
 	{ "streamdriver.mode", eCmdHdlrNonNegInt, 0 },
 	{ "streamdriver.authmode", eCmdHdlrString, 0 },
 	{ "streamdriver.permitexpiredcerts", eCmdHdlrString, 0 },
@@ -307,12 +321,12 @@ doOpenLstnSocks(tcpsrv_t *pSrv)
 
 
 static rsRetVal
-doRcvData(tcps_sess_t *pSess, char *buf, size_t lenBuf, ssize_t *piLenRcvd, int *const oserr)
+doRcvData(tcps_sess_t *pSess, char *buf, size_t lenBuf, ssize_t *piLenRcvd, int *const oserr, unsigned *nextIODirection)
 {
 	assert(pSess != NULL);
 	assert(piLenRcvd != NULL);
 	*piLenRcvd = lenBuf;
-	return netstrm.Rcv(pSess->pStrm, (uchar*) buf, piLenRcvd, oserr);
+	return netstrm.Rcv(pSess->pStrm, (uchar*) buf, piLenRcvd, oserr, nextIODirection);
 }
 
 static rsRetVal
@@ -403,6 +417,8 @@ createInstance(instanceConf_t **pinst)
 	inst->iSynBacklog = 0; /* default: unset */
 	inst->iTCPLstnMax = loadModConf->iTCPLstnMax;
 	inst->iTCPSessMax = loadModConf->iTCPSessMax;
+	inst->numWrkr = loadModConf->numWrkr;
+	inst->starvationMaxReads = loadModConf->starvationMaxReads;
 
 	inst->cnf_params->pszLstnPortFileName = NULL;
 
@@ -473,6 +489,8 @@ static rsRetVal addInstance(void __attribute__((unused)) *pVal, uchar *pNewVal)
 	inst->iAddtlFrameDelim = cs.iAddtlFrameDelim;
 	inst->iTCPLstnMax = cs.iTCPLstnMax;
 	inst->iTCPSessMax = cs.iTCPSessMax;
+	inst->numWrkr = DEFAULT_NUMWRKR;
+	inst->starvationMaxReads = DEFAULT_STARVATIONMAXREADS;
 	inst->iStrmDrvrMode = cs.iStrmDrvrMode;
 
 finalize_it:
@@ -497,6 +515,8 @@ addListner(modConfData_t *modConf, instanceConf_t *inst)
 	CHKiRet(tcpsrv.SetCBOnRegularClose(pOurTcpsrv, onRegularClose));
 	CHKiRet(tcpsrv.SetCBOnErrClose(pOurTcpsrv, onErrClose));
 	/* params */
+	CHKiRet(tcpsrv.SetNumWrkr(pOurTcpsrv, inst->numWrkr));
+	CHKiRet(tcpsrv.SetStarvationMaxReads(pOurTcpsrv, inst->starvationMaxReads));
 	CHKiRet(tcpsrv.SetKeepAlive(pOurTcpsrv, inst->bKeepAlive));
 	CHKiRet(tcpsrv.SetKeepAliveIntvl(pOurTcpsrv, inst->iKeepAliveIntvl));
 	CHKiRet(tcpsrv.SetKeepAliveProbes(pOurTcpsrv, inst->iKeepAliveProbes));
@@ -652,6 +672,8 @@ CODESTARTnewInpInst
 			inst->pszStrmDrvrCertFile = (uchar*)es_str2cstr(pvals[i].val.d.estr, NULL);
 		} else if(!strcmp(inppblk.descr[i].name, "streamdriver.name")) {
 			inst->pszStrmDrvrName = (uchar*)es_str2cstr(pvals[i].val.d.estr, NULL);
+		} else if(!strcmp(inppblk.descr[i].name, "starvationprotection.maxreads")) {
+			inst->starvationMaxReads = (unsigned) pvals[i].val.d.n;
 		} else if(!strcmp(inppblk.descr[i].name, "gnutlsprioritystring")) {
 			inst->gnutlsPriorityString = (uchar*)es_str2cstr(pvals[i].val.d.estr, NULL);
 		} else if(!strcmp(inppblk.descr[i].name, "permittedpeer")) {
@@ -685,6 +707,8 @@ CODESTARTnewInpInst
 			inst->iTCPSessMax = (int) pvals[i].val.d.n;
 		} else if(!strcmp(inppblk.descr[i].name, "maxlisteners")) {
 			inst->iTCPLstnMax = (int) pvals[i].val.d.n;
+		} else if(!strcmp(inppblk.descr[i].name, "workerthreads")) {
+			inst->numWrkr = (int) pvals[i].val.d.n;
 		} else if(!strcmp(inppblk.descr[i].name, "supportoctetcountedframing")) {
 			inst->cnf_params->bSuppOctetFram = (int) pvals[i].val.d.n;
 		} else if(!strcmp(inppblk.descr[i].name, "keepalive")) {
@@ -723,6 +747,8 @@ CODESTARTbeginCnfLoad
 	/* init our settings */
 	loadModConf->iTCPSessMax = 200;
 	loadModConf->iTCPLstnMax = 20;
+	loadModConf->numWrkr = DEFAULT_NUMWRKR;
+	loadModConf->starvationMaxReads = DEFAULT_STARVATIONMAXREADS;
 	loadModConf->bSuppOctetFram = 1;
 	loadModConf->iStrmDrvrMode = 0;
 	loadModConf->iStrmDrvrExtendedCertCheck = 0;
@@ -800,9 +826,13 @@ CODESTARTsetModCnf
 			}
 		} else if(!strcmp(modpblk.descr[i].name, "maxsessions")) {
 			loadModConf->iTCPSessMax = (int) pvals[i].val.d.n;
+		} else if(!strcmp(modpblk.descr[i].name, "starvationprotection.maxreads")) {
+			loadModConf->starvationMaxReads = (unsigned) pvals[i].val.d.n;
 		} else if(!strcmp(modpblk.descr[i].name, "maxlisteners") ||
 			  !strcmp(modpblk.descr[i].name, "maxlistners")) { /* keep old name for a while */
 			loadModConf->iTCPLstnMax = (int) pvals[i].val.d.n;
+		} else if(!strcmp(modpblk.descr[i].name, "workerthreads")) {
+			loadModConf->numWrkr = (int) pvals[i].val.d.n;
 		} else if(!strcmp(modpblk.descr[i].name, "keepalive")) {
 			loadModConf->bKeepAlive = (int) pvals[i].val.d.n;
 		} else if(!strcmp(modpblk.descr[i].name, "keepalive.probes")) {
@@ -1078,7 +1108,6 @@ CODESTARTafterRun
 	tcpsrv_etry_t *del;
 	while(etry != NULL) {
 		iRet = tcpsrv.Destruct(&etry->tcpsrv);
-		// TODO: check iRet, reprot error
 		del = etry;
 		etry = etry->next;
 		free(del);
