@@ -21,11 +21,11 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *       http://www.apache.org/licenses/LICENSE-2.0
  *       -or-
  *       see COPYING.ASL20 in the source distribution
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -57,7 +57,6 @@ MODULE_TYPE_NOKEEP
 
 
 /* static data */
-DEFobjCurrIf(errmsg);
 
 /* internal structures
  */
@@ -73,7 +72,7 @@ typedef struct wrkrInstanceData {
 
 
 BEGINinitConfVars		/* (re)set config variables to default values */
-CODESTARTinitConfVars 
+CODESTARTinitConfVars
 ENDinitConfVars
 
 
@@ -127,7 +126,6 @@ parseName(uchar **buf, char *name, unsigned lenName)
 	--lenName; /* reserve space for '\0' */
 	i = 0;
 	while(**buf && **buf != '=' && lenName) {
-//dbgprintf("parseNAme, buf: %s\n", *buf);
 		name[i++] = **buf;
 		++(*buf), --lenName;
 	}
@@ -158,7 +156,6 @@ parseValue(uchar **buf, char *val, unsigned lenval)
 	}
 
 	while(**buf && **buf != termc && lenval) {
-//dbgprintf("parseValue, termc '%c', buf: %s\n", termc, *buf);
 		val[i++] = **buf;
 		++(*buf), --lenval;
 	}
@@ -169,7 +166,7 @@ finalize_it:
 }
 
 
-/* parse the audit record and create libee structure
+/* parse the audit record and create json structure
  */
 static rsRetVal
 audit_parse(uchar *buf, struct json_object **jsonRoot)
@@ -302,7 +299,6 @@ ENDparseSelectorAct
 
 BEGINmodExit
 CODESTARTmodExit
-	objRelease(errmsg, CORE_COMPONENT);
 ENDmodExit
 
 
@@ -342,7 +338,6 @@ CODEmodInit_QueryRegCFSLineHdlr
 		ABORT_FINALIZE(RS_RET_NO_MSG_PASSING);
 	}
 
-	iRet = objUse(errmsg, CORE_COMPONENT);
 ENDmodInit
 
 /* vi:set ai:
