@@ -157,7 +157,7 @@ finalize_it:
 
 
 BEGINinitConfVars		/* (re)set config variables to default values */
-CODESTARTinitConfVars 
+CODESTARTinitConfVars
 	resetConfigVariables(NULL, NULL);
 ENDinitConfVars
 
@@ -402,7 +402,7 @@ CODESTARTnewActInst
 			                "mmnormalize: 'variable' param can't be used with 'useRawMsg'. "
 			                "Ignoring 'variable', will use raw message.");
 		} else {
-			CHKmalloc(pData->varDescr = MALLOC(sizeof(msgPropDescr_t)));
+			CHKmalloc(pData->varDescr = malloc(sizeof(msgPropDescr_t)));
 			CHKiRet(msgPropDescrFill(pData->varDescr, (uchar*) varName, strlen(varName)));
 		}
 		free(varName);
