@@ -11,11 +11,11 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *       http://www.apache.org/licenses/LICENSE-2.0
  *       -or-
  *       see COPYING.ASL20 in the source distribution
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -51,7 +51,6 @@ MODULE_CNFNAME("omuxsock")
 /* internal structures
  */
 DEF_OMOD_STATIC_DATA
-DEFobjCurrIf(errmsg)
 DEFobjCurrIf(glbl)
 
 #define INVLD_SOCK -1
@@ -97,7 +96,7 @@ static modConfData_t *runModConf = NULL;/* modConf ptr to use for the current ex
 static pthread_mutex_t mutDoAct = PTHREAD_MUTEX_INITIALIZER;
 
 BEGINinitConfVars		/* (re)set config variables to default values */
-CODESTARTinitConfVars 
+CODESTARTinitConfVars
 	cs.tplName = NULL;
 	cs.sockName = NULL;
 ENDinitConfVars
@@ -133,7 +132,7 @@ setLegacyDfltTpl(void __attribute__((unused)) *pVal, uchar* newVal)
 
 	if(loadModConf != NULL && loadModConf->tplName != NULL) {
 		free(newVal);
-		errmsg.LogError(0, RS_RET_ERR, "omuxsock default template already set via module "
+		LogError(0, RS_RET_ERR, "omuxsock default template already set via module "
 			"global parameter - can no longer be changed");
 		ABORT_FINALIZE(RS_RET_ERR);
 	}
@@ -171,7 +170,7 @@ BEGINsetModCnf
 CODESTARTsetModCnf
 	pvals = nvlstGetParams(lst, &modpblk, NULL);
 	if(pvals == NULL) {
-		errmsg.LogError(0, RS_RET_MISSING_CNFPARAMS, "error processing module "
+		LogError(0, RS_RET_MISSING_CNFPARAMS, "error processing module "
 				"config parameters [module(...)]");
 		ABORT_FINALIZE(RS_RET_MISSING_CNFPARAMS);
 	}
@@ -187,7 +186,7 @@ CODESTARTsetModCnf
 		if(!strcmp(modpblk.descr[i].name, "template")) {
 			loadModConf->tplName = (uchar*)es_str2cstr(pvals[i].val.d.estr, NULL);
 			if(cs.tplName != NULL) {
-				errmsg.LogError(0, RS_RET_DUP_PARAM, "omuxsock: default template "
+				LogError(0, RS_RET_DUP_PARAM, "omuxsock: default template "
 						"was already set via legacy directive - may lead to inconsistent "
 						"results.");
 			}
@@ -301,13 +300,13 @@ openSocket(instanceData *pData)
 			eno, rs_strerror_r(eno, errStr, sizeof(errStr)));
 		pData->sock = INVLD_SOCK;
 		ABORT_FINALIZE(RS_RET_NO_SOCKET);
-		
+
 	}
 
 	/* set up server address structure */
 	memset(&pData->addr, 0, sizeof(pData->addr));
-        pData->addr.sun_family = AF_UNIX;
-        strncpy(pData->addr.sun_path, (char*)pData->sockName, sizeof(pData->addr.sun_path));
+	pData->addr.sun_family = AF_UNIX;
+	strncpy(pData->addr.sun_path, (char*)pData->sockName, sizeof(pData->addr.sun_path));
 	pData->addr.sun_path[sizeof(pData->addr.sun_path)-1] = '\0';
 
 finalize_it:
@@ -350,7 +349,7 @@ CODESTARTdoAction
 	pthread_mutex_lock(&mutDoAct);
 	CHKiRet(doTryResume(pWrkrData->pData));
 
-	iMaxLine = glbl.GetMaxLine();
+	iMaxLine = glbl.GetMaxLine(runModConf->pConf);
 
 	DBGPRINTF(" omuxsock:%s\n", pWrkrData->pData->sockName);
 
@@ -383,9 +382,9 @@ CODE_STD_STRING_REQUESTparseSelectorAct(1)
 	if(*(p-1) == ';')
 		--p;
 	CHKiRet(cflineParseTemplateName(&p, *ppOMSR, 0, 0, getDfltTpl()));
-	
+
 	if(cs.sockName == NULL) {
-		errmsg.LogError(0, RS_RET_NO_SOCK_CONFIGURED, "No output socket configured for omuxsock\n");
+		LogError(0, RS_RET_NO_SOCK_CONFIGURED, "No output socket configured for omuxsock\n");
 		ABORT_FINALIZE(RS_RET_NO_SOCK_CONFIGURED);
 	}
 
@@ -412,7 +411,6 @@ freeConfigVars(void)
 BEGINmodExit
 CODESTARTmodExit
 	/* release what we no longer need */
-	objRelease(errmsg, CORE_COMPONENT);
 	objRelease(glbl, CORE_COMPONENT);
 
 	freeConfigVars();
@@ -444,7 +442,6 @@ INITLegCnfVars
 	*ipIFVersProvided = CURR_MOD_IF_VERSION; /* we only support the current interface specification */
 CODEmodInit_QueryRegCFSLineHdlr
 	CHKiRet(objUse(glbl, CORE_COMPONENT));
-	CHKiRet(objUse(errmsg, CORE_COMPONENT));
 
 	CHKiRet(regCfSysLineHdlr((uchar *)"omuxsockdefaulttemplate", 0, eCmdHdlrGetWord, setLegacyDfltTpl,
 		NULL, NULL));
