@@ -904,6 +904,10 @@ rsksiCtxNew(void) {
 	ctx->dirGID = -1;
 	ctx->fCreateMode = 0644;
 	ctx->fDirCreateMode = 0700;
+#if KSI_SDK_VER_MAJOR == 3 && KSI_SDK_VER_MINOR < 22
+	ctx->roundCount = 0;
+	ctx->bRoundLock = 0;
+#endif
 	ctx->syncMode = LOGSIG_SYNCHRONOUS;
 	ctx->signer_state = SIGNER_IDLE;
 	ctx->disabled = false;
@@ -1754,6 +1758,21 @@ cleanup:
 	return ret;
 }
 
+static KSI_DataHash* clone_hash(KSI_CTX *ksi_ctx, const KSI_DataHash* hash) {
+	int res = KSI_UNKNOWN_ERROR;
+	const unsigned char *imprint = NULL;
+	size_t imprint_len = 0;
+	KSI_DataHash* tmp = NULL;
+
+	if (hash == NULL) return NULL;
+	res = KSI_DataHash_getImprint(hash, &imprint, &imprint_len);
+	if (res != KSI_OK) return NULL;
+	res = KSI_DataHash_fromImprint(ksi_ctx, imprint, imprint_len, &tmp);
+	if (res != KSI_OK) return NULL;
+
+	return tmp;
+}
+
 static bool
 process_requests_async(rsksictx ctx, KSI_CTX *ksi_ctx, KSI_AsyncService *as) {
 	bool ret = false;
@@ -1761,6 +1780,7 @@ process_requests_async(rsksictx ctx, KSI_CTX *ksi_ctx, KSI_AsyncService *as) {
 	int res = KSI_OK, tmpRes;
 	KSI_AsyncHandle *reqHandle = NULL;
 	KSI_AsyncHandle *respHandle = NULL;
+	KSI_DataHash *clonedHash = NULL;
 	KSI_AggregationReq *req = NULL;
 	KSI_Config *config = NULL;
 	KSI_Integer *level;
@@ -1784,6 +1804,14 @@ process_requests_async(rsksictx ctx, KSI_CTX *ksi_ctx, KSI_AsyncService *as) {
 			break;
 		}
 
+#if KSI_SDK_VER_MAJOR == 3 && KSI_SDK_VER_MINOR < 22
+		if (p != 0 && ctx->roundCount > 0) {
+			ctx->roundCount--;
+		} else {
+			ctx->bRoundLock = 0;
+			ctx->roundCount = 0;
+		}
+#endif
 		state = KSI_ASYNC_STATE_UNDEFINED;
 
 		CHECK_KSI_API(KSI_AsyncHandle_getState(respHandle, &state), ctx, "KSI_AsyncHandle_getState");
@@ -1837,10 +1865,28 @@ process_requests_async(rsksictx ctx, KSI_CTX *ksi_ctx, KSI_AsyncService *as) {
 		if(item->status != QITEM_WAITING)
 			continue;
 
+		/* Due to a bug in libksi it is possible that async signer may send out
+		 * more signing requests than permitted by the gateway. Workaround is to
+		 * keep track of signing requests here.
+		 */
+#if KSI_SDK_VER_MAJOR == 3 && KSI_SDK_VER_MINOR < 22
+		if (ctx->roundCount >= ctx->max_requests) ctx->bRoundLock = 1;
+		if (ctx->bRoundLock) break;
+#endif
+
+
+		/* The data hash is produced in another thread by another KSI_CTX and
+		 * libksi internal uses KSI_DataHash cache to reduce the amount of
+		 * memory allocations by recycling old objects. Lets clone the hash
+		 * value with current KSI_CTX as we can not be sure that this thread is
+		 * not affecting the data hash cache operated by another thread.
+		 */
+		clonedHash = clone_hash(ksi_ctx, item->root);
 		CHECK_KSI_API(KSI_AggregationReq_new(ksi_ctx, &req), ctx, "KSI_AggregationReq_new");
 		CHECK_KSI_API(KSI_AggregationReq_setRequestHash((KSI_AggregationReq*)req,
-			KSI_DataHash_ref(item->root)), ctx,
+			clonedHash), ctx,
 			"KSI_AggregationReq_setRequestHash");
+		clonedHash = NULL;
 		CHECK_KSI_API(KSI_Integer_new(ksi_ctx, item->intarg2, &level), ctx,
 			"KSI_Integer_new");
 		CHECK_KSI_API(KSI_AggregationReq_setRequestLevel(req, level), ctx,
@@ -1853,11 +1899,9 @@ process_requests_async(rsksictx ctx, KSI_CTX *ksi_ctx, KSI_AsyncService *as) {
 
 		if (res == KSI_OK) {
 			item->status = QITEM_SENT;
-
-			tmpRes=KSI_AsyncService_run(as, NULL, NULL);
-			if(tmpRes!=KSI_OK)
-				reportKSIAPIErr(ctx, NULL, "KSI_AsyncService_run", tmpRes);
-
+#if KSI_SDK_VER_MAJOR == 3 && KSI_SDK_VER_MINOR < 22
+			ctx->roundCount++;
+#endif
 		} else {
 			reportKSIAPIErr(ctx, NULL, "KSI_AsyncService_addRequest", res);
 			KSI_AsyncHandle_free(reqHandle);
@@ -1865,8 +1909,14 @@ process_requests_async(rsksictx ctx, KSI_CTX *ksi_ctx, KSI_AsyncService *as) {
 			item->ksi_status = res;
 			break;
 		}
-	}
 
+		if (i != 0 && i % ctx->max_requests == 0) {
+			CHECK_KSI_API(KSI_AsyncService_run(as, NULL, NULL), ctx,
+				"KSI_AsyncService_run");
+		}
+	}
+	CHECK_KSI_API(KSI_AsyncService_run(as, NULL, NULL), ctx,
+		"KSI_AsyncService_run");
 
 	/* Save all consequent fulfilled responses in the front of the queue to the signature file */
 	while(ProtectedQueue_count(ctx->signer_queue)) {
@@ -1902,6 +1952,7 @@ process_requests_async(rsksictx ctx, KSI_CTX *ksi_ctx, KSI_AsyncService *as) {
 	ret = true;
 
 cleanup:
+	KSI_DataHash_free(clonedHash);
 	KSI_AsyncService_getPendingCount(as, &p);
 	return ret;
 }
