@@ -223,6 +223,7 @@ osslGlblInit(void)
 PRAGMA_DIAGNOSTIC_PUSH
 PRAGMA_IGNORE_Wdeprecated_declarations
 
+#ifndef OPENSSL_NO_ENGINE
 	// Initialize OpenSSL engine library
 	ENGINE_load_builtin_engines();
 	/* Register all of them for every algorithm they collectively implement */
@@ -243,6 +244,10 @@ PRAGMA_IGNORE_Wdeprecated_declarations
 	}
 	// Free the engine reference when done
 	ENGINE_free(osslEngine);
+#else
+	DBGPRINTF("osslGlblInit: OpenSSL compiled without ENGINE support - ENGINE support disabled\n");
+#endif /* OPENSSL_NO_ENGINE */
+
 PRAGMA_DIAGNOSTIC_POP
 }
 
@@ -251,7 +256,9 @@ void
 osslGlblExit(void)
 {
 	DBGPRINTF("openssl: entering osslGlblExit\n");
+#ifndef OPENSSL_NO_ENGINE
 	ENGINE_cleanup();
+#endif
 	ERR_free_strings();
 	EVP_cleanup();
 	CRYPTO_cleanup_all_ex_data();
@@ -435,6 +442,11 @@ net_ossl_osslCtxInit(net_ossl_t *pThis, const SSL_METHOD *method)
 	SSL_CTX_set_timeout(pThis->ctx, 30);	/* Default Session Timeout, TODO: Make configureable */
 	SSL_CTX_set_mode(pThis->ctx, SSL_MODE_AUTO_RETRY);
 
+#if OPENSSL_VERSION_NUMBER >= 0x10100000L
+	/* Enable Support for automatic ephemeral/temporary DH parameter selection. */
+	SSL_CTX_set_dh_auto(pThis->ctx, 1);
+#endif
+
 #if OPENSSL_VERSION_NUMBER >= 0x10002000L
 #	if OPENSSL_VERSION_NUMBER <= 0x101010FFL
 	/* Enable Support for automatic EC temporary key parameter selection. */
@@ -638,7 +650,7 @@ net_ossl_chkonepeername(net_ossl_t *pThis, X509 *certpeer, uchar *pszPeerID, int
 #endif
 	char *x509name = NULL;
 	DEFiRet;
-	
+
 	if (certpeer == NULL) {
 		ABORT_FINALIZE(RS_RET_TLS_NO_CERT);
 	}
@@ -1145,7 +1157,10 @@ net_ossl_verify_cookie(SSL *ssl, const unsigned char *cookie, unsigned int cooki
 static rsRetVal
 net_ossl_init_engine(__attribute__((unused)) net_ossl_t *pThis)
 {
+	// OpenSSL Engine Support feature relies on an outdated version of OpenSSL and is
+	// strictly experimental. No support or guarantees are provided. Use at your own risk.
 	DEFiRet;
+#ifndef OPENSSL_NO_ENGINE
 	const char *engine_id = NULL;
 	const char *engine_name = NULL;
 
@@ -1189,6 +1204,9 @@ PRAGMA_IGNORE_Wdeprecated_declarations
 		DBGPRINTF("net_ossl_init_engine: use openssl default Engine");
 	}
 PRAGMA_DIAGNOSTIC_POP
+#else
+	DBGPRINTF("net_ossl_init_engine: OpenSSL compiled without ENGINE support - ENGINE support disabled\n");
+#endif /* OPENSSL_NO_ENGINE */
 
 	RETiRet;
 }
