@@ -45,7 +45,7 @@ BEGINinterface(netstrm) /* name must also be changed in ENDinterface macro! */
 	rsRetVal (*Destruct)(netstrm_t **ppThis);
 	rsRetVal (*AbortDestruct)(netstrm_t **ppThis);
 	rsRetVal (*AcceptConnReq)(netstrm_t *pThis, netstrm_t **ppNew);
-	rsRetVal (*Rcv)(netstrm_t *pThis, uchar *pRcvBuf, ssize_t *pLenBuf, int *oserr);
+	rsRetVal (*Rcv)(netstrm_t *pThis, uchar *pRcvBuf, ssize_t *pLenBuf, int *oserr, unsigned *nextIODirection);
 	rsRetVal (*Send)(netstrm_t *pThis, uchar *pBuf, ssize_t *pLenBuf);
 	rsRetVal (*Connect)(netstrm_t *pThis, int family, unsigned char *port, unsigned char *host, char *device);
 	rsRetVal (*GetRemoteHName)(netstrm_t *pThis, uchar **pszName);
@@ -93,7 +93,7 @@ BEGINinterface(netstrm) /* name must also be changed in ENDinterface macro! */
 	rsRetVal (*SetDrvrTlsKeyFile)(netstrm_t *pThis, const uchar* file);
 	rsRetVal (*SetDrvrTlsCertFile)(netstrm_t *pThis, const uchar* file);
 ENDinterface(netstrm)
-#define netstrmCURR_IF_VERSION 16 /* increment whenever you change the interface structure! */
+#define netstrmCURR_IF_VERSION 17 /* increment whenever you change the interface structure! */
 /* interface version 3 added GetRemAddr()
  * interface version 4 added EnableKeepAlive() -- rgerhards, 2009-06-02
  * interface version 5 changed return of CheckConnection from void to rsRetVal -- alorbach, 2012-09-06
@@ -103,6 +103,7 @@ ENDinterface(netstrm)
  * interface version 9 added SetGnutlsPriorityString -- PascalWithopf, 2017-08-08
  * interface version 10 added oserr parameter to Rcv() -- rgerhards, 2017-09-04
  * interface version 16 CRL file -- Oracle, 2022-01-16
+ * interface version 17 added nextIODirection parameter to Rcv() -- rgehards, 2025-04-17
  * */
 
 /* prototypes */
