@@ -34,8 +34,6 @@
 #include "obj.h"
 #include "nsd.h"
 #include "netstrm.h"
-#include "nssel.h"
-#include "nspoll.h"
 #include "netstrms.h"
 #include "rsconf.h"
 
@@ -539,8 +537,6 @@ ENDObjClassInit(netstrms)
 
 BEGINmodExit
 CODESTARTmodExit
-	nsselClassExit();
-	nspollClassExit();
 	netstrmsClassExit();
 	netstrmClassExit(); /* we use this object, so we must exit it after we are finished */
 ENDmodExit
@@ -558,7 +554,5 @@ CODESTARTmodInit
 
 	/* Initialize all classes that are in our module - this includes ourselfs */
 	CHKiRet(netstrmClassInit(pModInfo));
-	CHKiRet(nsselClassInit(pModInfo));
-	CHKiRet(nspollClassInit(pModInfo));
 	CHKiRet(netstrmsClassInit(pModInfo));
 ENDmodInit
