@@ -4,7 +4,7 @@
  * implemented by concrete classes. As such, no nsd data type itself
  * is defined.
  *
- * Copyright 2008-2012 Adiscon GmbH.
+ * Copyright 2008-2025 Adiscon GmbH.
  *
  * This file is part of the rsyslog runtime library.
  *
@@ -27,16 +27,6 @@
 
 #include <sys/socket.h>
 
-/**
- * The following structure is a set of descriptors that need to be processed.
- * This set will be the result of the epoll call and be used
- * in the actual request processing stage. -- rgerhards, 2011-01-24
- */
-struct nsd_epworkset_s {
-	int id;
-	void *pUsr;
-};
-
 enum nsdsel_waitOp_e {
 	NSDSEL_RD = 1,
 	NSDSEL_WR = 2,
@@ -52,7 +42,7 @@ BEGINinterface(nsd) /* name must also be changed in ENDinterface macro! */
 	rsRetVal (*Construct)(nsd_t **ppThis);
 	rsRetVal (*Destruct)(nsd_t **ppThis);
 	rsRetVal (*Abort)(nsd_t *pThis);
-	rsRetVal (*Rcv)(nsd_t *pThis, uchar *pRcvBuf, ssize_t *pLenBuf, int *oserr);
+	rsRetVal (*Rcv)(nsd_t *pThis, uchar *pRcvBuf, ssize_t *pLenBuf, int *oserr, unsigned *nextIODirection);
 	rsRetVal (*Send)(nsd_t *pThis, uchar *pBuf, ssize_t *pLenBuf);
 	rsRetVal (*Connect)(nsd_t *pThis, int family, unsigned char *port, unsigned char *host, char *device);
 	rsRetVal (*AcceptConnReq)(nsd_t *pThis, nsd_t **ppThis);
@@ -113,23 +103,4 @@ ENDinterface(nsd)
  * interface version 11 added oserr to Rcv() signature -- rgerhards, 2017-09-04
  */
 
-/* interface  for the select call */
-BEGINinterface(nsdsel) /* name must also be changed in ENDinterface macro! */
-	rsRetVal (*Construct)(nsdsel_t **ppThis);
-	rsRetVal (*Destruct)(nsdsel_t **ppThis);
-	rsRetVal (*Add)(nsdsel_t *pNsdsel, nsd_t *pNsd, nsdsel_waitOp_t waitOp);
-	rsRetVal (*Select)(nsdsel_t *pNsdsel, int *piNumReady);
-	rsRetVal (*IsReady)(nsdsel_t *pNsdsel, nsd_t *pNsd, nsdsel_waitOp_t waitOp, int *pbIsReady);
-ENDinterface(nsdsel)
-#define nsdselCURR_IF_VERSION 1 /* increment whenever you change the interface structure! */
-
-/* interface  for the epoll call */
-BEGINinterface(nsdpoll) /* name must also be changed in ENDinterface macro! */
-	rsRetVal (*Construct)(nsdpoll_t **ppThis);
-	rsRetVal (*Destruct)(nsdpoll_t **ppThis);
-	rsRetVal (*Ctl)(nsdpoll_t *pNsdpoll, nsd_t *pNsd, int id, void *pUsr, int mode, int op);
-	rsRetVal (*Wait)(nsdpoll_t *pNsdpoll, int timeout, int *numReady, nsd_epworkset_t workset[]);
-ENDinterface(nsdpoll)
-#define nsdpollCURR_IF_VERSION 1 /* increment whenever you change the interface structure! */
-
 #endif /* #ifndef INCLUDED_NSD_H */
