@@ -50,7 +50,6 @@
 #include "netstrm.h"
 #include "netstrms.h"
 #include "nsd_ptcp.h"
-#include "nsdsel_gtls.h"
 #include "nsd_gtls.h"
 #include "unicode-helper.h"
 #include "rsconf.h"
@@ -142,7 +141,7 @@ doRetry(nsd_gtls_t *pNsd)
 		case gtlsRtry_None:
 		default:
 			assert(0); /* this shall not happen! */
-			dbgprintf("ERROR: pNsd->rtryCall %d invalid in nsdsel_gtls.c:%d\n",
+			dbgprintf("ERROR: pNsd->rtryCall %d invalid in nsd_gtls.c:%d\n",
 				pNsd->rtryCall, __LINE__);
 			gnuRet = 0; /* if it happens, we have at least a defined behaviour... ;) */
 			break;
@@ -597,14 +596,14 @@ uchar *gtlsStrerror(int error)
 
 /* try to receive a record from the remote peer. This works with
  * our own abstraction and handles local buffering and EAGAIN.
- * See details on local buffering in Rcv(9 header-comment.
+ * See details on local buffering in Rcv() header-comment.
  * This function MUST only be called when the local buffer is
  * empty. Calling it otherwise will cause losss of current buffer
  * data.
  * rgerhards, 2008-06-24
  */
 rsRetVal
-gtlsRecordRecv(nsd_gtls_t *pThis)
+gtlsRecordRecv(nsd_gtls_t *const pThis, unsigned int* nextIODirection)
 {
 	ssize_t lenRcvd;
 	DEFiRet;
@@ -648,18 +647,10 @@ gtlsRecordRecv(nsd_gtls_t *pThis)
 	} else if(lenRcvd == GNUTLS_E_AGAIN || lenRcvd == GNUTLS_E_INTERRUPTED) {
 sslerragain:
 		/* Check if the underlaying file descriptor needs to read or write data!*/
-		if (gnutls_record_get_direction(pThis->sess) == gtlsDir_READ) {
-			pThis->rtryCall = gtlsRtry_recv;
-			dbgprintf("GnuTLS receive requires a retry, this most probably is OK and no error condition\n");
-			ABORT_FINALIZE(RS_RET_RETRY);
-		} else {
-			uchar *pErr = gtlsStrerror(lenRcvd);
-			LogError(0, RS_RET_GNUTLS_ERR, "GnuTLS receive error %zd has wrong read direction(wants write) "
-				"- this could be caused by a broken connection. GnuTLS reports: %s\n",
-				lenRcvd, pErr);
-			free(pErr);
-			ABORT_FINALIZE(RS_RET_GNUTLS_ERR);
-		}
+		pThis->rtryCall = gtlsRtry_recv; /* _recv refers to the gnutls call, not socket layer! */
+		dbgprintf("GnuTLS receive requires a retry, this most probably is OK and no error condition\n");
+		*nextIODirection = (gnutls_record_get_direction(pThis->sess) == 0) ? NSDSEL_RD : NSDSEL_WR;
+		ABORT_FINALIZE(RS_RET_RETRY);
 	} else {
 		int gnuRet = lenRcvd;
 		ABORTgnutls;
@@ -1056,6 +1047,8 @@ gtlsChkPeerFingerprint(nsd_gtls_t *pThis, gnutls_x509_crt_t *pCert)
 finalize_it:
 	if(pstrFingerprint != NULL)
 		cstrDestruct(&pstrFingerprint);
+	if(pstrFingerprintSha256 != NULL)
+		cstrDestruct(&pstrFingerprintSha256);
 	RETiRet;
 }
 
@@ -1919,6 +1912,16 @@ CheckConnection(nsd_t __attribute__((unused)) *pNsd)
 }
 
 
+/* Provide access to the underlying OS socket.
+ */
+static rsRetVal
+GetSock(nsd_t *pNsd, int *pSock)
+{
+	nsd_gtls_t *pThis = (nsd_gtls_t*) pNsd;
+	return nsd_ptcp.GetSock(pThis->pTcp, pSock);
+}
+
+
 /* get the remote hostname. The returned hostname must be freed by the caller.
  * rgerhards, 2008-04-25
  */
@@ -2100,7 +2103,7 @@ if (error_position != NULL) {
  * buffer. -- rgerhards, 2008-06-23
  */
 static rsRetVal
-Rcv(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf, int *const oserr)
+Rcv(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf, int *const oserr, unsigned *const nextIODirection)
 {
 	DEFiRet;
 	ssize_t iBytesCopy; /* how many bytes are to be copied to the client buffer? */
@@ -2111,7 +2114,7 @@ Rcv(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf, int *const oserr)
 		ABORT_FINALIZE(RS_RET_CONNECTION_ABORTREQ);
 
 	if(pThis->iMode == 0) {
-		CHKiRet(nsd_ptcp.Rcv(pThis->pTcp, pBuf, pLenBuf, oserr));
+		CHKiRet(nsd_ptcp.Rcv(pThis->pTcp, pBuf, pLenBuf, oserr, nextIODirection));
 		FINALIZE;
 	}
 
@@ -2141,7 +2144,7 @@ Rcv(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf, int *const oserr)
 	 * the request from buffer contents.
 	 */
 	if(pThis->lenRcvBuf == -1) { /* no data present, must read */
-		CHKiRet(gtlsRecordRecv(pThis));
+		CHKiRet(gtlsRecordRecv(pThis, nextIODirection));
 	}
 
 	if(pThis->lenRcvBuf == 0) { /* EOS */
@@ -2162,8 +2165,7 @@ Rcv(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf, int *const oserr)
 	*pLenBuf = iBytesCopy;
 
 finalize_it:
-	if (iRet != RS_RET_OK &&
-		iRet != RS_RET_RETRY) {
+	if (iRet != RS_RET_OK && iRet != RS_RET_RETRY) {
 		/* We need to free the receive buffer in error error case unless a retry is wanted. , if we
 		 * allocated one. -- rgerhards, 2008-12-03 -- moved here by alorbach, 2015-12-01
 		 */
@@ -2192,6 +2194,10 @@ Send(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf)
 	DEFiRet;
 	ISOBJ_TYPE_assert(pThis, nsd_gtls);
 
+	if(pThis->rtryCall == gtlsRtry_recv) {
+		CHKiRet(doRetry(pThis));
+		FINALIZE;
+	}
 	if(pThis->bAbortConn)
 		ABORT_FINALIZE(RS_RET_CONNECTION_ABORTREQ);
 
@@ -2435,6 +2441,7 @@ CODESTARTobjQueryInterface(nsd_gtls)
 	pIf->Rcv = Rcv;
 	pIf->Send = Send;
 	pIf->Connect = Connect;
+	pIf->GetSock = GetSock;
 	pIf->SetSock = SetSock;
 	pIf->SetMode = SetMode;
 	pIf->SetAuthMode = SetAuthMode;
@@ -2496,7 +2503,6 @@ ENDObjClassInit(nsd_gtls)
 
 BEGINmodExit
 CODESTARTmodExit
-	nsdsel_gtlsClassExit();
 	nsd_gtlsClassExit();
 	pthread_mutex_destroy(&mutGtlsStrerror);
 ENDmodExit
@@ -2514,7 +2520,6 @@ CODESTARTmodInit
 
 	/* Initialize all classes that are in our module - this includes ourselfs */
 	CHKiRet(nsd_gtlsClassInit(pModInfo)); /* must be done after tcps_sess, as we use it */
-	CHKiRet(nsdsel_gtlsClassInit(pModInfo)); /* must be done after tcps_sess, as we use it */
 
 	pthread_mutex_init(&mutGtlsStrerror, NULL);
 ENDmodInit
