@@ -49,7 +49,6 @@
 #include "datetime.h"
 #include "net_ossl.h"	// Include OpenSSL Helpers
 #include "nsd_ptcp.h"
-#include "nsdsel_ossl.h"
 #include "nsd_ossl.h"
 #include "unicode-helper.h"
 #include "rsconf.h"
@@ -214,7 +213,7 @@ long BIO_debug_callback(BIO *bio, int cmd, const char __attribute__((unused)) *a
  * rgerhards, 2008-06-24
  */
 rsRetVal
-osslRecordRecv(nsd_ossl_t *pThis)
+osslRecordRecv(nsd_ossl_t *pThis, unsigned *const nextIODirection)
 {
 	ssize_t lenRcvd;
 	DEFiRet;
@@ -259,7 +258,7 @@ sslerr:
 			/* Output error and abort */
 			nsd_ossl_lastOpenSSLErrorMsg(pThis, lenRcvd, pThis->pNetOssl->ssl, LOG_INFO,
 				"osslRecordRecv", "SSL_read 1");
-			iRet = RS_RET_NO_ERRCODE;
+			iRet = RS_RET_TLS_ERR_SYSCALL;
 			/* Check for underlaying socket errors **/
 			if (	errno == ECONNRESET) {
 				DBGPRINTF("osslRecordRecv: SSL_ERROR_SYSCALL Errno %d, connection reset by peer\n",
@@ -286,9 +285,13 @@ sslerr:
 		}
 	}
 
-// TODO: Check if MORE retry logic needed?
 
 finalize_it:
+	if(pThis->rtryCall != osslRtry_None && pThis->rtryOsslErr == SSL_ERROR_WANT_WRITE) {
+		*nextIODirection = NSDSEL_WR;
+	} else {
+		*nextIODirection = NSDSEL_RD;
+	}
 	dbgprintf("osslRecordRecv return. nsd %p, iRet %d, lenRcvd %zd, lenRcvBuf %d, ptrRcvBuf %d\n",
 	pThis, iRet, lenRcvd, pThis->lenRcvBuf, pThis->ptrRcvBuf);
 	RETiRet;
@@ -305,7 +308,7 @@ osslInitSession(nsd_ossl_t *pThis, osslSslState_t osslType) /* , nsd_ossl_t *pSe
 	if(!(pThis->pNetOssl->ssl = SSL_new(pThis->pNetOssl->ctx))) {
 		pThis->pNetOssl->ssl = NULL;
 		nsd_ossl_lastOpenSSLErrorMsg(pThis, 0, pThis->pNetOssl->ssl, LOG_ERR, "osslInitSession", "SSL_new");
-		ABORT_FINALIZE(RS_RET_NO_ERRCODE);
+		ABORT_FINALIZE(RS_RET_TLS_BASEINIT_FAIL);
 	}
 
 	// Set SSL_MODE_AUTO_RETRY to SSL obj
@@ -781,6 +784,15 @@ CheckConnection(nsd_t __attribute__((unused)) *pNsd)
 }
 
 
+/* Provide access to the underlying OS socket.
+ */
+static rsRetVal
+GetSock(nsd_t *pNsd, int *pSock)
+{
+	nsd_ossl_t *pThis = (nsd_ossl_t*) pNsd;
+	return nsd_ptcp.GetSock(pThis->pTcp, pSock);
+}
+
 /* get the remote hostname. The returned hostname must be freed by the caller.
  * rgerhards, 2008-04-25
  */
@@ -1046,7 +1058,7 @@ finalize_it:
  * buffer. -- rgerhards, 2008-06-23
  */
 static rsRetVal
-Rcv(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf, int *const oserr)
+Rcv(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf, int *const oserr, unsigned *const nextIODirection)
 {
 	DEFiRet;
 	ssize_t iBytesCopy; /* how many bytes are to be copied to the client buffer? */
@@ -1058,7 +1070,7 @@ Rcv(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf, int *const oserr)
 		ABORT_FINALIZE(RS_RET_CONNECTION_ABORTREQ);
 
 	if(pThis->iMode == 0) {
-		CHKiRet(nsd_ptcp.Rcv(pThis->pTcp, pBuf, pLenBuf, oserr));
+		CHKiRet(nsd_ptcp.Rcv(pThis->pTcp, pBuf, pLenBuf, oserr, nextIODirection));
 		FINALIZE;
 	}
 
@@ -1087,7 +1099,7 @@ Rcv(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf, int *const oserr)
 	 * the request from buffer contents.
 	 */
 	if(pThis->lenRcvBuf == -1) { /* no data present, must read */
-		CHKiRet(osslRecordRecv(pThis));
+		CHKiRet(osslRecordRecv(pThis, nextIODirection));
 	}
 
 	if(pThis->lenRcvBuf == 0) { /* EOS */
@@ -1179,7 +1191,7 @@ Send(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf)
 				/* Output error and abort */
 				nsd_ossl_lastOpenSSLErrorMsg(pThis, iSent, pThis->pNetOssl->ssl, LOG_INFO,
 					"Send", "SSL_write");
-				iRet = RS_RET_NO_ERRCODE;
+				iRet = RS_RET_TLS_ERR_SYSCALL;
 				/* Check for underlaying socket errors **/
 				if (	errno == ECONNRESET) {
 					dbgprintf("Send: SSL_ERROR_SYSCALL Connection was reset by remote\n");
@@ -1490,6 +1502,7 @@ CODESTARTobjQueryInterface(nsd_ossl)
 	pIf->Rcv = Rcv;
 	pIf->Send = Send;
 	pIf->Connect = Connect;
+	pIf->GetSock = GetSock;
 	pIf->SetSock = SetSock;
 	pIf->SetMode = SetMode;
 	pIf->SetAuthMode = SetAuthMode;
@@ -1547,7 +1560,6 @@ ENDObjClassInit(nsd_ossl)
 
 BEGINmodExit
 CODESTARTmodExit
-	nsdsel_osslClassExit();
 	nsd_osslClassExit();
 	net_osslClassExit();
 ENDmodExit
@@ -1567,5 +1579,4 @@ CODESTARTmodInit
 	DBGPRINTF("modInit\n");
 	CHKiRet(net_osslClassInit(pModInfo)); /* must be done after tcps_sess, as we use it */
 	CHKiRet(nsd_osslClassInit(pModInfo)); /* must be done after tcps_sess, as we use it */
-	CHKiRet(nsdsel_osslClassInit(pModInfo)); /* must be done after tcps_sess, as we use it */
 ENDmodInit
