@@ -2,7 +2,7 @@
  *
  * An implementation of the nsd interface for plain tcp sockets.
  *
- * Copyright 2007-2024 Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2007-2025 Rainer Gerhards and Adiscon GmbH.
  *
  * This file is part of the rsyslog runtime library.
  *
@@ -49,8 +49,6 @@
 #include "net.h"
 #include "netstrms.h"
 #include "netstrm.h"
-#include "nsdsel_ptcp.h"
-#include "nsdpoll_ptcp.h"
 #include "nsd_ptcp.h"
 #include "prop.h"
 #include "dnscache.h"
@@ -471,11 +469,13 @@ AcceptConnReq(nsd_t *pNsd, nsd_t **ppNew)
 	assert(ppNew != NULL);
 	ISOBJ_TYPE_assert(pThis, nsd_ptcp);
 
-	do {
-		iNewSock = accept(pThis->sock, (struct sockaddr*) &addr, &addrlen);
-	} while(iNewSock < 0 && (errno == EINTR || errno == EAGAIN));
+	iNewSock = accept(pThis->sock, (struct sockaddr*) &addr, &addrlen);
 
 	if(iNewSock < 0) {
+		if(errno == EINTR || errno == EAGAIN) {
+			ABORT_FINALIZE(RS_RET_NO_MORE_DATA);
+		}
+
 		LogMsg(errno, RS_RET_ACCEPT_ERR, LOG_WARNING,
 			"nds_ptcp: error accepting connection on socket %d", pThis->sock);
 		ABORT_FINALIZE(RS_RET_ACCEPT_ERR);
@@ -775,7 +775,7 @@ finalize_it:
  * rgerhards, 2008-03-17
  */
 static rsRetVal
-Rcv(nsd_t *pNsd, uchar *pRcvBuf, ssize_t *pLenBuf, int *const oserr)
+Rcv(nsd_t *pNsd, uchar *pRcvBuf, ssize_t *pLenBuf, int *const oserr, unsigned *const nextIODirection)
 {
 	char errStr[1024];
 	DEFiRet;
@@ -789,13 +789,18 @@ Rcv(nsd_t *pNsd, uchar *pRcvBuf, ssize_t *pLenBuf, int *const oserr)
 
 	*pLenBuf = recv(pThis->sock, pRcvBuf, *pLenBuf, MSG_DONTWAIT);
 	*oserr = errno;
+	*nextIODirection = NSDSEL_RD;
 
 	if(*pLenBuf == 0) {
 		ABORT_FINALIZE(RS_RET_CLOSED);
 	} else if (*pLenBuf < 0) {
-		rs_strerror_r(errno, errStr, sizeof(errStr));
-		dbgprintf("error during recv on NSD %p: %s\n", pNsd, errStr);
-		ABORT_FINALIZE(RS_RET_RCV_ERR);
+		if(*oserr == EINTR || *oserr == EAGAIN) {
+			ABORT_FINALIZE(RS_RET_RETRY);
+		} else {
+			rs_strerror_r(errno, errStr, sizeof(errStr));
+			dbgprintf("error during recv on NSD %p: %s\n", pNsd, errStr);
+			ABORT_FINALIZE(RS_RET_RCV_ERR);
+		}
 	}
 
 finalize_it:
@@ -1134,10 +1139,6 @@ ENDObjClassInit(nsd_ptcp)
 
 BEGINmodExit
 CODESTARTmodExit
-#	ifdef HAVE_EPOLL_CREATE /* module only available if epoll() is supported! */
-	nsdpoll_ptcpClassExit();
-#	endif
-	nsdsel_ptcpClassExit();
 	nsd_ptcpClassExit();
 ENDmodExit
 
@@ -1154,10 +1155,4 @@ CODESTARTmodInit
 
 	/* Initialize all classes that are in our module - this includes ourselfs */
 	CHKiRet(nsd_ptcpClassInit(pModInfo)); /* must be done after tcps_sess, as we use it */
-	CHKiRet(nsdsel_ptcpClassInit(pModInfo)); /* must be done after tcps_sess, as we use it */
-#	ifdef HAVE_EPOLL_CREATE /* module only available if epoll() is supported! */
-	CHKiRet(nsdpoll_ptcpClassInit(pModInfo)); /* must be done after tcps_sess, as we use it */
-#	endif
 ENDmodInit
-/* vi:set ai:
- */
