@@ -48,7 +48,7 @@
  *
  * File begun on 2008-01-04 by RGerhards
  *
- * Copyright 2008-2019 Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2008-2024 Rainer Gerhards and Adiscon GmbH.
  *
  * This file is part of the rsyslog runtime library.
  *
@@ -125,7 +125,7 @@ static rsRetVal objInfoNotImplementedDummy(void __attribute__((unused)) *pThis)
  * must be provided an objInfo_t pointer.
  */
 #define objInfoIsImplemented(pThis, method) \
-	(pThis->objMethods[method] != objInfoNotImplementedDummy)
+	(pThis->objMethods[method] != (rsRetVal (*)(void *, ...)) objInfoNotImplementedDummy)
 
 /* construct an object Info object. Each class shall do this on init. The
  * resulting object shall be cached during the lifetime of the class and each
@@ -154,10 +154,10 @@ InfoConstruct(objInfo_t **ppThis, uchar *pszID, int iObjVers,
 	pThis->QueryIF = pQueryIF;
 	pThis->pModInfo = pModInfo;
 
-	pThis->objMethods[0] = pConstruct;
-	pThis->objMethods[1] = pDestruct;
+	pThis->objMethods[0] = (rsRetVal (*)(void *, ...)) pConstruct;
+	pThis->objMethods[1] = (rsRetVal (*)(void *, ...)) pDestruct;
 	for(i = 2 ; i < OBJ_NUM_METHODS ; ++i) {
-		pThis->objMethods[i] = objInfoNotImplementedDummy;
+		pThis->objMethods[i] = (rsRetVal (*)(void *, ...)) objInfoNotImplementedDummy;
 	}
 
 	*ppThis = pThis;
@@ -192,7 +192,7 @@ InfoDestruct(objInfo_t **ppThis)
 static rsRetVal
 InfoSetMethod(objInfo_t *pThis, objMethod_t objMethod, rsRetVal (*pHandler)(void*))
 {
-	pThis->objMethods[objMethod] = pHandler;
+	pThis->objMethods[objMethod] = (rsRetVal (*)(void *, ...)) pHandler;
 	return RS_RET_OK;
 }
 
@@ -786,7 +786,7 @@ finalize_it:
  * of the trailer. Header must already have been processed.
  * rgerhards, 2008-01-11
  */
-static rsRetVal objDeserializeProperties(obj_t *pObj, rsRetVal (*objSetProperty)(), strm_t *pStrm)
+static rsRetVal objDeserializeProperties(obj_t *pObj, rsRetVal (*objSetProperty)(void*, ...), strm_t *pStrm)
 {
 	DEFiRet;
 	var_t *pVar = NULL;
@@ -867,7 +867,8 @@ Deserialize(void *ppObj, uchar *pszTypeExpected, strm_t *pStrm, rsRetVal (*fFixu
 	CHKiRet(pObjInfo->objMethods[objMethod_CONSTRUCT](&pObj));
 
 	/* we got the object, now we need to fill the properties */
-	CHKiRet(objDeserializeProperties(pObj, pObjInfo->objMethods[objMethod_SETPROPERTY], pStrm));
+	CHKiRet(objDeserializeProperties(pObj,
+		(rsRetVal (*)(void*, ...)) pObjInfo->objMethods[objMethod_SETPROPERTY], pStrm));
 
 	/* check if we need to call a fixup function that modifies the object
 	 * before it is finalized. -- rgerhards, 2008-01-13
@@ -898,8 +899,10 @@ finalize_it:
  */
 rsRetVal
 objDeserializeWithMethods(void *ppObj, uchar *pszTypeExpected, int lenTypeExpected, strm_t *pStrm,
-rsRetVal (*fFixup)(obj_t*,void*), void *pUsr, rsRetVal (*objConstruct)(), rsRetVal (*objConstructFinalize)(),
-rsRetVal (*objDeserialize)())
+	rsRetVal (*fFixup)(obj_t*,void*), void *pUsr,
+	rsRetVal (*objConstruct)(void *, ...),
+	rsRetVal (*objConstructFinalize)(void *, ...),
+	rsRetVal (*objDeserialize)(void *, ...))
 {
 	DEFiRet;
 	rsRetVal iRetLocal;
@@ -1007,7 +1010,8 @@ DeserializePropBag(obj_t *pObj, strm_t *pStrm)
 	CHKiRet(FindObjInfo((char*)cstrGetSzStrNoNULL(pstrID), &pObjInfo));
 
 	/* we got the object, now we need to fill the properties */
-	CHKiRet(objDeserializeProperties(pObj, pObjInfo->objMethods[objMethod_SETPROPERTY], pStrm));
+	CHKiRet(objDeserializeProperties(pObj,
+		(rsRetVal (*)(void*, ...)) pObjInfo->objMethods[objMethod_SETPROPERTY], pStrm));
 
 finalize_it:
 	if(pstrID != NULL)
