@@ -58,29 +58,14 @@ static char hexdigit[16] =
 	{'0', '1', '2', '3', '4', '5', '6', '7', '8',
 	 '9', 'A', 'B', 'C', 'D', 'E', 'F' };
 
-/* This is the list of all parsers known to us.
- * This is also used to unload all modules on shutdown.
- */
-parserList_t *pParsLstRoot = NULL;
-
-/* this is the list of the default parsers, to be used if no others
- * are specified.
- */
-parserList_t *pDfltParsLst = NULL;
-
-int bSupportCompressionExtension = 1;
-
-/* intialize (but NOT allocate) a parser list. Primarily meant as a hook
- * which can be used to extend the list in the future. So far, just sets
- * it to NULL.
- */
-static rsRetVal
-InitParserList(parserList_t **pListRoot)
-{
-	*pListRoot = NULL;
-	return RS_RET_OK;
-}
-
+BEGINobjDestruct(parser) /* be sure to specify the object type also in END and CODESTART macros! */
+CODESTARTobjDestruct(parser)
+	DBGPRINTF("destructing parser '%s'\n", pThis->pName);
+	if(pThis->pInst != NULL) {
+		pThis->pModule->mod.pm.freeParserInst(pThis->pInst);
+	}
+	free(pThis->pName);
+ENDobjDestruct(parser)
 
 /* destruct a parser list. The list elements are destroyed, but the parser objects
  * themselves are not modified. (That is done at a late stage during rsyslogd
@@ -148,12 +133,12 @@ printParserList(parserList_t *pList)
 
 /* find a parser based on the provided name */
 static rsRetVal
-FindParser(parser_t **ppParser, uchar *pName)
+FindParser(parserList_t *pParserListRoot, parser_t **ppParser, uchar *pName)
 {
 	parserList_t *pThis;
 	DEFiRet;
-	
-	for(pThis = pParsLstRoot ; pThis != NULL ; pThis = pThis->pNext) {
+
+	for(pThis = pParserListRoot ; pThis != NULL ; pThis = pThis->pNext) {
 		if(ustrcmp(pThis->pParser->pName, pName) == 0) {
 			*ppParser = pThis->pParser;
 			FINALIZE;	/* found it, iRet still eq. OK! */
@@ -180,10 +165,10 @@ AddDfltParser(uchar *pName)
 	parser_t *pParser;
 	DEFiRet;
 
-	CHKiRet(FindParser(&pParser, pName));
-	CHKiRet(AddParserToList(&pDfltParsLst, pParser));
+	CHKiRet(FindParser(loadConf->parsers.pParsLstRoot, &pParser, pName));
+	CHKiRet(AddParserToList(&loadConf->parsers.pDfltParsLst, pParser));
 	DBGPRINTF("Parser '%s' added to default parser set.\n", pName);
-	
+
 finalize_it:
 	RETiRet;
 }
@@ -252,7 +237,7 @@ static rsRetVal parserConstructFinalize(parser_t *pThis)
 	DEFiRet;
 
 	ISOBJ_TYPE_assert(pThis, parser);
-	CHKiRet(AddParserToList(&pParsLstRoot, pThis));
+	CHKiRet(AddParserToList(&loadConf->parsers.pParsLstRoot, pThis));
 	DBGPRINTF("Parser '%s' added to list of available parsers.\n", pThis->pName);
 
 finalize_it:
@@ -295,15 +280,6 @@ finalize_it:
 		free(pParser);
 	RETiRet;
 }
-BEGINobjDestruct(parser) /* be sure to specify the object type also in END and CODESTART macros! */
-CODESTARTobjDestruct(parser)
-	DBGPRINTF("destructing parser '%s'\n", pThis->pName);
-	if(pThis->pInst != NULL) {
-		pThis->pModule->mod.pm.freeParserInst(pThis->pInst);
-	}
-	free(pThis->pName);
-ENDobjDestruct(parser)
-
 
 /* uncompress a received message if it is compressed.
  * pMsg->pszRawMsg buffer is updated.
@@ -316,7 +292,7 @@ static rsRetVal uncompressMessage(smsg_t *pMsg)
 	uLongf iLenDefBuf;
 	uchar *pszMsg;
 	size_t lenMsg;
-	
+
 	assert(pMsg != NULL);
 	pszMsg = pMsg->pszRawMsg;
 	lenMsg = pMsg->iLenRawMsg;
@@ -324,7 +300,8 @@ static rsRetVal uncompressMessage(smsg_t *pMsg)
 	/* we first need to check if we have a compressed record. If so,
 	 * we must decompress it.
 	 */
-	if(lenMsg > 0 && *pszMsg == 'z' && bSupportCompressionExtension) { /* compressed data present? */
+	if(lenMsg > 0 && *pszMsg == 'z' &&
+		runConf->globals.bSupportCompressionExtension) { /* compressed data present? */
 		/* we have compressed data, so let's deflate it. We support a maximum
 		 * message size of iMaxLine. If it is larger, an error message is logged
 		 * and the message is dropped. We do NOT try to decompress larger messages
@@ -333,7 +310,7 @@ static rsRetVal uncompressMessage(smsg_t *pMsg)
 		 * feature.
 		 */
 		int ret;
-		iLenDefBuf = glbl.GetMaxLine();
+		iLenDefBuf = glbl.GetMaxLine(runConf);
 		CHKmalloc(deflateBuf = malloc(iLenDefBuf + 1));
 		ret = uncompress((uchar *) deflateBuf, &iLenDefBuf, (uchar *) pszMsg+1, lenMsg-1);
 		DBGPRINTF("Compressed message uncompressed with status %d, length: new %ld, old %d.\n",
@@ -412,7 +389,7 @@ SanitizeMsg(smsg_t *pMsg)
 	 * compatible to recent IETF developments, we allow the user to
 	 * turn on/off this handling.  rgerhards, 2007-07-23
 	 */
-	if(glbl.GetParserDropTrailingLFOnReception()
+	if(glbl.GetParserDropTrailingLFOnReception(runConf)
 	   && lenMsg > 0 && pszMsg[lenMsg-1] == '\n') {
 		DBGPRINTF("dropped LF at very end of message (DropTrailingLF is set)\n");
 		lenMsg--;
@@ -433,15 +410,15 @@ SanitizeMsg(smsg_t *pMsg)
 	int bNeedSanitize = 0;
 	for(iSrc = 0 ; iSrc < lenMsg ; iSrc++) {
 		if(pszMsg[iSrc] < 32) {
-			if(glbl.GetParserSpaceLFOnReceive() && pszMsg[iSrc] == '\n') {
+			if(glbl.GetParserSpaceLFOnReceive(runConf) && pszMsg[iSrc] == '\n') {
 				pszMsg[iSrc] = ' ';
-			} else if(pszMsg[iSrc] == '\0' || glbl.GetParserEscapeControlCharactersOnReceive()) {
+			} else if(pszMsg[iSrc] == '\0' || glbl.GetParserEscapeControlCharactersOnReceive(runConf)) {
 				bNeedSanitize = 1;
-				if (!glbl.GetParserSpaceLFOnReceive()) {
+				if (!glbl.GetParserSpaceLFOnReceive(runConf)) {
 					break;
 			    }
 			}
-		} else if(pszMsg[iSrc] > 127 && glbl.GetParserEscape8BitCharactersOnReceive()) {
+		} else if(pszMsg[iSrc] > 127 && glbl.GetParserEscape8BitCharactersOnReceive(runConf)) {
 			bNeedSanitize = 1;
 			break;
 		}
@@ -456,7 +433,7 @@ SanitizeMsg(smsg_t *pMsg)
 	/* now copy over the message and sanitize it. Note that up to iSrc-1 there was
 	 * obviously no need to sanitize, so we can go over that quickly...
 	 */
-	iMaxLine = glbl.GetMaxLine();
+	iMaxLine = glbl.GetMaxLine(runConf);
 	maxDest = lenMsg * 4; /* message can grow at most four-fold */
 
 	if(maxDest > iMaxLine)
@@ -477,16 +454,16 @@ SanitizeMsg(smsg_t *pMsg)
 	}
 	iDst = iSrc;
 	while(iSrc < lenMsg && iDst < maxDest - 3) { /* leave some space if last char must be escaped */
-		if((pszMsg[iSrc] < 32) && (pszMsg[iSrc] != '\t' || glbl.GetParserEscapeControlCharacterTab())) {
+		if((pszMsg[iSrc] < 32) && (pszMsg[iSrc] != '\t' || glbl.GetParserEscapeControlCharacterTab(runConf))) {
 			/* note: \0 must always be escaped, the rest of the code currently
 			 * can not handle it! -- rgerhards, 2009-08-26
 			 */
-			if(pszMsg[iSrc] == '\0' || glbl.GetParserEscapeControlCharactersOnReceive()) {
+			if(pszMsg[iSrc] == '\0' || glbl.GetParserEscapeControlCharactersOnReceive(runConf)) {
 				/* we are configured to escape control characters. Please note
 				 * that this most probably break non-western character sets like
 				 * Japanese, Korean or Chinese. rgerhards, 2007-07-17
 				 */
-				if (glbl.GetParserEscapeControlCharactersCStyle()) {
+				if (glbl.GetParserEscapeControlCharactersCStyle(runConf)) {
 					pDst[iDst++] = '\\';
 
 					switch (pszMsg[iSrc]) {
@@ -528,15 +505,15 @@ SanitizeMsg(smsg_t *pMsg)
 					}
 
 				} else {
-					pDst[iDst++] = glbl.GetParserControlCharacterEscapePrefix();
+					pDst[iDst++] = glbl.GetParserControlCharacterEscapePrefix(runConf);
 					pDst[iDst++] = '0' + ((pszMsg[iSrc] & 0300) >> 6);
 					pDst[iDst++] = '0' + ((pszMsg[iSrc] & 0070) >> 3);
 					pDst[iDst++] = '0' + ((pszMsg[iSrc] & 0007));
 				}
 			}
 
-		} else if(pszMsg[iSrc] > 127 && glbl.GetParserEscape8BitCharactersOnReceive()) {
-			if (glbl.GetParserEscapeControlCharactersCStyle()) {
+		} else if(pszMsg[iSrc] > 127 && glbl.GetParserEscape8BitCharactersOnReceive(runConf)) {
+			if (glbl.GetParserEscapeControlCharactersCStyle(runConf)) {
 				pDst[iDst++] = '\\';
 				pDst[iDst++] = 'x';
 
@@ -548,7 +525,7 @@ SanitizeMsg(smsg_t *pMsg)
 				/* In this case, we also do the conversion. Note that this most
 				 * probably breaks European languages. -- rgerhards, 2010-01-27
 				 */
-				pDst[iDst++] = glbl.GetParserControlCharacterEscapePrefix();
+				pDst[iDst++] = glbl.GetParserControlCharacterEscapePrefix(runConf);
 				pDst[iDst++] = '0' + ((pszMsg[iSrc] & 0300) >> 6);
 				pDst[iDst++] = '0' + ((pszMsg[iSrc] & 0070) >> 3);
 				pDst[iDst++] = '0' + ((pszMsg[iSrc] & 0007));
@@ -642,12 +619,12 @@ ParseMsg(smsg_t *pMsg)
 	 * will cause it to happen. After that, access to the unsanitized message is no
 	 * loger possible.
 	 */
-	pParserList = ruleset.GetParserList(ourConf, pMsg);
+	pParserList = ruleset.GetParserList(runConf, pMsg);
 	if(pParserList == NULL) {
-		pParserList = pDfltParsLst;
+		pParserList = runConf->parsers.pDfltParsLst;
 	}
 	DBGPRINTF("parse using parser list %p%s.\n", pParserList,
-		  (pParserList == pDfltParsLst) ? " (the default list)" : "");
+		  (pParserList == runConf->parsers.pDfltParsLst) ? " (the default list)" : "");
 
 	bIsSanitized = RSFALSE;
 	bPRIisParsed = RSFALSE;
@@ -692,6 +669,28 @@ ParseMsg(smsg_t *pMsg)
 finalize_it:
 	RETiRet;
 }
+
+/* This destroys the master parserlist and all of its parser entries.
+ * Parser modules are NOT unloaded, rsyslog does that at a later stage
+ * for all dynamically loaded modules.
+ */
+static rsRetVal
+destroyMasterParserList(parserList_t *pParserListRoot)
+{
+	DEFiRet;
+	parserList_t *pParsLst;
+	parserList_t *pParsLstDel;
+
+	pParsLst = pParserListRoot;
+	while(pParsLst != NULL) {
+		parserDestruct(&pParsLst->pParser);
+		pParsLstDel = pParsLst;
+		pParsLst = pParsLst->pNext;
+		free(pParsLstDel);
+	}
+	RETiRet;
+}
+
 /* queryInterface function-- rgerhards, 2009-11-03
  */
 BEGINobjQueryInterface(parser)
@@ -713,39 +712,18 @@ CODESTARTobjQueryInterface(parser)
 	pIf->SetDoPRIParsing = SetDoPRIParsing;
 	pIf->ParseMsg = ParseMsg;
 	pIf->SanitizeMsg = SanitizeMsg;
-	pIf->InitParserList = InitParserList;
 	pIf->DestructParserList = DestructParserList;
 	pIf->AddParserToList = AddParserToList;
 	pIf->AddDfltParser = AddDfltParser;
 	pIf->FindParser = FindParser;
+	pIf->destroyMasterParserList = destroyMasterParserList;
 finalize_it:
 ENDobjQueryInterface(parser)
 
-/* This destroys the master parserlist and all of its parser entries. MUST only be
- * done when the module is shut down. Parser modules are NOT unloaded, rsyslog
- * does that at a later stage for all dynamically loaded modules.
- */
-static void
-destroyMasterParserList(void)
-{
-	parserList_t *pParsLst;
-	parserList_t *pParsLstDel;
-
-	pParsLst = pParsLstRoot;
-	while(pParsLst != NULL) {
-		parserDestruct(&pParsLst->pParser);
-		pParsLstDel = pParsLst;
-		pParsLst = pParsLst->pNext;
-		free(pParsLstDel);
-	}
-}
-
 /* Exit our class.
  * rgerhards, 2009-11-04
  */
 BEGINObjClassExit(parser, OBJ_IS_CORE_MODULE) /* class, version */
-	DestructParserList(&pDfltParsLst);
-	destroyMasterParserList();
 	objRelease(glbl, CORE_COMPONENT);
 	objRelease(datetime, CORE_COMPONENT);
 	objRelease(ruleset, CORE_COMPONENT);
@@ -761,7 +739,4 @@ BEGINObjClassInit(parser, 1, OBJ_IS_CORE_MODULE) /* class, version */
 	CHKiRet(objUse(glbl, CORE_COMPONENT));
 	CHKiRet(objUse(datetime, CORE_COMPONENT));
 	CHKiRet(objUse(ruleset, CORE_COMPONENT));
-
-	InitParserList(&pParsLstRoot);
-	InitParserList(&pDfltParsLst);
 ENDObjClassInit(parser)
