@@ -290,7 +290,7 @@ BEGINobjConstruct(rsconf) /* be sure to specify the object type also in END macr
 	CHKiRet(dynstats_initCnf(&pThis->dynstats_buckets));
 	CHKiRet(perctile_initCnf(&pThis->perctile_buckets));
 	CHKiRet(llInit(&pThis->rulesets.llRulesets, rulesetDestructForLinkedList,
-			rulesetKeyDestruct, strcasecmp));
+			rulesetKeyDestruct, (int (*)(void*, void*)) strcasecmp));
 finalize_it:
 ENDobjConstruct(rsconf)
 
