@@ -163,6 +163,7 @@ tplToString(struct template *__restrict__ const pTpl,
 	unsigned short bMustBeFreed = 0;
 	uchar *pVal;
 	rs_size_t iLenVal = 0;
+	int need_comma = 0;
 
 	if(pTpl->pStrgen != NULL) {
 		CHKiRet(pTpl->pStrgen(pMsg, iparam));
@@ -230,15 +231,24 @@ tplToString(struct template *__restrict__ const pTpl,
 			if(iBuf + iLenVal + extra_space >= iparam->lenBuf) /* we reserve one char for the final \0! */
 				CHKiRet(ExtendBuf(iparam, iBuf + iLenVal + 1));
 
+			if(need_comma) {
+				memcpy(iparam->param + iBuf, ", ", 2);
+				iBuf += 2;
+			}
 			memcpy(iparam->param + iBuf, pVal, iLenVal);
 			iBuf += iLenVal;
 			if(pTpl->optFormatEscape == JSONF) {
-				memcpy(iparam->param + iBuf,
-					(pTpe->pNext == NULL) ? "}\n" : ", ", 2);
-				iBuf += 2;
+				need_comma = 1;
 			}
 		}
 
+		if((pTpl->optFormatEscape == JSONF) && (pTpe->pNext == NULL)) {
+			/* space was reserved while processing field above
+			   (via extra_space in ExtendBuf() new size formula. */
+			memcpy(iparam->param + iBuf, "}\n", 2);
+			iBuf += 2;
+		}
+
 		if(bMustBeFreed) {
 			free(pVal);
 			bMustBeFreed = 0;
@@ -1461,7 +1471,8 @@ createPropertyTpe(struct template *pTpl, struct cnfobj *o)
 	int spifno1stsp = 0;
 	int mandatory = 0;
 	int frompos = -1;
-	int topos = -1;
+	int topos = 0;
+	int topos_set = 0;
 	int fieldnum = -1;
 	int fielddelim = 9; /* default is HT (USACSII 9) */
 	int fixedwidth = 0;
@@ -1545,6 +1556,7 @@ createPropertyTpe(struct template *pTpl, struct cnfobj *o)
 			bComplexProcessing = 1;
 		} else if(!strcmp(pblkProperty.descr[i].name, "position.to")) {
 			topos = pvals[i].val.d.n;
+			topos_set = 1;
 			bComplexProcessing = 1;
 		} else if(!strcmp(pblkProperty.descr[i].name, "position.relativetoend")) {
 			bPosRelativeToEnd = pvals[i].val.d.n;
@@ -1726,9 +1738,9 @@ createPropertyTpe(struct template *pTpl, struct cnfobj *o)
 	}
 
 	/* sanity check */
-	if(topos == -1 && frompos != -1)
+	if(topos_set == 0 && frompos != -1)
 		topos = 2000000000; /* large enough ;) */
-	if(frompos == -1 && topos != -1)
+	if(frompos == -1 && topos_set != 0)
 		frompos = 0;
 	if(bPosRelativeToEnd) {
 		if(topos > frompos) {
@@ -1737,7 +1749,7 @@ createPropertyTpe(struct template *pTpl, struct cnfobj *o)
 			ABORT_FINALIZE(RS_RET_ERR);
 		}
 	} else {
-		if(topos < frompos) {
+		if((topos >= 0) && (topos < frompos)) {
 			LogError(0, RS_RET_ERR, "position.to=%d is lower than postion.from=%d\n",
 				topos, frompos);
 			ABORT_FINALIZE(RS_RET_ERR);
