@@ -1,14 +1,12 @@
 #!/bin/bash
 # This file is part of the rsyslog project, released under ASL 2.0
+. ${srcdir:=.}/diag.sh init
+export NUMMESSAGES=100
 export ES_DOWNLOAD=elasticsearch-6.0.0.tar.gz
 export ES_PORT=19200
-. $srcdir/diag.sh download-elasticsearch
-. $srcdir/diag.sh stop-elasticsearch
-. $srcdir/diag.sh prepare-elasticsearch
-. $srcdir/diag.sh start-elasticsearch
+ensure_elasticsearch_ready
 
-. ${srcdir:=.}/diag.sh init
-. $srcdir/diag.sh es-init
+init_elasticsearch
 generate_conf
 add_conf '
 template(name="tpl" type="string"
@@ -22,12 +20,10 @@ module(load="../plugins/omelasticsearch/.libs/omelasticsearch")
 				 bulkmode="on")
 '
 startup_vg
-injectmsg  0 100
+injectmsg
 wait_queueempty
 shutdown_when_empty
 wait_shutdown_vg
-. $srcdir/diag.sh es-getdata 100 $ES_PORT
-seq_check  0 99
-. $srcdir/diag.sh stop-elasticsearch
-. $srcdir/diag.sh cleanup-elasticsearch
+es_getdata $NUMMESSAGES $ES_PORT
+seq_check
 exit_test
