@@ -4,9 +4,7 @@
 export ES_PORT=19200
 export NUMMESSAGES=5000 # test is pretty slow, so use a low number
 export QUEUE_EMPTY_CHECK_FUNC=es_shutdown_empty_check
-download_elasticsearch
-prepare_elasticsearch
-start_elasticsearch
+ensure_elasticsearch_ready
 
 init_elasticsearch
 generate_conf
@@ -31,5 +29,4 @@ wait_shutdown_vg
 check_exit_vg
 es_getdata
 seq_check
-cleanup_elasticsearch
 exit_test
