@@ -3,9 +3,9 @@
 . ${srcdir:=.}/diag.sh init
 export ES_DOWNLOAD=elasticsearch-6.0.0.tar.gz
 export ES_PORT=19200
-download_elasticsearch
-prepare_elasticsearch
-start_elasticsearch
+export NUMMESSAGES=10000
+export QUEUE_EMPTY_CHECK_FUNC=es_shutdown_empty_check
+ensure_elasticsearch_ready
 
 init_elasticsearch
 generate_conf
@@ -14,24 +14,24 @@ template(name="tpl" type="string"
 	 string="{\"msgnum\":\"%msg:F,58:2%\"}")
 
 module(load="../plugins/omelasticsearch/.libs/omelasticsearch")
-:msg, contains, "msgnum:" action(type="omelasticsearch"
+:msg, contains, "msgnum:" {
+			action(type="omelasticsearch"
 				 template="tpl"
 				 serverport=`echo $ES_PORT`
 				 searchIndex="rsyslog_testbench"
 				 bulkmode="on"
 				 errorFile="./'${RSYSLOG_DYNNAME}'.errorfile")
+}
 '
 startup
-injectmsg  0 10000
+injectmsg  0 $NUMMESSAGES
 shutdown_when_empty
 wait_shutdown 
-es_getdata 10000 $ES_PORT
-if [ -f ${RSYSLOG_DYNNAME}.errorfile ]
-then
-    echo "error: error file exists!"
-    cat ${RSYSLOG_DYNNAME}.errorfile
+es_getdata $NUMMESSAGES $ES_PORT
+if [ -f ${RSYSLOG_DYNNAME}.errorfile ]; then
+    printf 'error: error file exists!\n'
+    cat -n ${RSYSLOG_DYNNAME}.errorfile
     error_exit 1
 fi
-seq_check  0 9999 19200
-cleanup_elasticsearch
+seq_check
 exit_test
