@@ -2,17 +2,16 @@
 # This file is part of the rsyslog project, released under ASL 2.0
 . ${srcdir:=.}/diag.sh init
 export ES_DOWNLOAD=elasticsearch-6.0.0.tar.gz
-download_elasticsearch
-prepare_elasticsearch
-start_elasticsearch
+ensure_elasticsearch_ready
 
 init_elasticsearch
 echo '{ "name" : "foo" }
 {"name": bar"}
 {"name": "baz"}
-{"name": foz"}' > inESData.inputfile
+{"name": foz"}' > $RSYSLOG_DYNNAME.inESData.inputfile
 generate_conf
 add_conf '
+global(workDirectory="'$RSYSLOG_DYNNAME.spool'")
 # Note: we must mess up with the template, because we can not
 # instruct ES to put further constraints on the data type and
 # values. So we require integer and make sure it is none.
@@ -37,23 +36,20 @@ ruleset(name="foo") {
 	 interleaved="on")
 }
 
-input(type="imfile" File="./inESData.inputfile"
+input(type="imfile" File="'$RSYSLOG_DYNNAME.'inESData.inputfile"
       Tag="foo"
-      StateFile="stat-file1"
       Severity="info"
       ruleset="foo")
 '
 startup
 shutdown_when_empty
 wait_shutdown
-rm -f inESData.inputfile
 
-python $srcdir/elasticsearch-error-format-check.py interleaved
+$PYTHON $srcdir/elasticsearch-error-format-check.py interleaved
 
 if [ $? -ne 0 ]
 then
     echo "error: Format for error file different! " $?
     exit 1
 fi
-cleanup_elasticsearch
 exit_test
