@@ -2,7 +2,7 @@
 # This file is part of the rsyslog project, released under GPLv3
 echo ===============================================================================
 echo \[failover-no-basic.sh\]: basic test for failover functionality - no failover
-. $srcdir/diag.sh init
+. ${srcdir:=.}/diag.sh init
 generate_conf
 add_conf '
 $RepeatedMsgReduction off
