@@ -5,7 +5,7 @@ generate_conf
 add_conf '
 module(load="../plugins/imtcp/.libs/imtcp")
 input(type="imtcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port"
-	notifyonconnectionclose="on")
+	notifyonconnectionopen="on" notifyonconnectionclose="on")
 
 :msg, contains, "msgnum:" {
 	action(type="omfile" file=`echo $RSYSLOG2_OUT_LOG`)
@@ -19,5 +19,6 @@ assign_tcpflood_port $RSYSLOG_DYNNAME.tcpflood_port
 tcpflood -m1 -M"\"<129>Mar 10 01:00:00 172.20.245.8 tag: msgnum:1\""
 shutdown_when_empty
 wait_shutdown
+content_check "connection established with "
 content_check "closed by remote peer "
 exit_test
