@@ -12,17 +12,24 @@ if [ $no_liblogging_stdlog -ne 0 ];then
   echo "liblogging-stdlog not available - skipping test"
   exit 77
 fi
-. $srcdir/diag.sh init
-. $srcdir/diag.sh startup imuxsock_traillf_root.conf
+. ${srcdir:=.}/diag.sh init
+generate_conf
+add_conf '
+$ModLoad ../plugins/imuxsock/.libs/imuxsock
+
+$template outfmt,"%msg:%\n"
+local1.*	action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
+'
+startup
 # send a message with trailing LF
 ./syslog_caller -fsyslog_inject-l -m1
 # the sleep below is needed to prevent too-early termination of rsyslogd
 ./msleep 100
-. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-. $srcdir/diag.sh wait-shutdown	# we need to wait until rsyslogd is finished!
-cmp rsyslog.out.log $srcdir/resultdata/imuxsock_traillf.log
+shutdown_when_empty # shut down rsyslogd when done processing messages
+wait_shutdown	# we need to wait until rsyslogd is finished!
+cmp $RSYSLOG_OUT_LOG $srcdir/resultdata/imuxsock_traillf.log
 if [ ! $? -eq 0 ]; then
 echo "imuxsock_traillf_root.sh failed"
 exit 1
 fi;
-. $srcdir/diag.sh exit
+exit_test
