@@ -1,23 +1,23 @@
 #!/bin/bash
 # added 2015-11-17 by rgerhards
 # This file is part of the rsyslog project, released under ASL 2.0
-# Note: the aim of this test is to test against misadressing, so we do
+# Note: the aim of this test is to test against misaddressing, so we do
 # not actually check the output
 
 uname
-if [ `uname` = "FreeBSD" ] ; then
+if [ $(uname) = "FreeBSD" ] ; then
    echo "This test currently does not work on FreeBSD."
    exit 77
 fi
 
 echo ===============================================================================
-echo \[json_null.sh\]: test for json containung \"null\" value
-. $srcdir/diag.sh init
+echo \[json_null.sh\]: test for json containing \"null\" value
+. ${srcdir:=.}/diag.sh init
 generate_conf
 add_conf '
 module(load="../plugins/mmjsonparse/.libs/mmjsonparse")
 module(load="../plugins/imtcp/.libs/imtcp")
-input(type="imtcp" port="'$TCPFLOOD_PORT'")
+input(type="imtcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port")
 
 # we must make sure the template contains a reference to the 
 # data item with null value
