@@ -2,13 +2,13 @@
 # added 2015-11-17 by rgerhards
 # This file is part of the rsyslog project, released under ASL 2.0
 echo ===============================================================================
-echo \[json_null_array.sh\]: test for json containung \"null\" value
+echo \[json_null_array.sh\]: test for json containing \"null\" value
 . ${srcdir:=.}/diag.sh init
 generate_conf
 add_conf '
 module(load="../plugins/mmjsonparse/.libs/mmjsonparse")
 module(load="../plugins/imtcp/.libs/imtcp")
-input(type="imtcp" port="'$TCPFLOOD_PORT'")
+input(type="imtcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port")
 
 template(name="outfmt" type="string" string="%$.data%\n")
 
