@@ -23,14 +23,9 @@ tcpflood -m1 -M "\"<129>Mar 10 01:00:00 172.20.245.8 tag: FFFF:FFFF:FFFF:FFFF:FF
 
 shutdown_when_empty
 wait_shutdown
-echo ' 0:0:0:0:0:0:0:0
+export EXPECTED=' 0:0:0:0:0:0:0:0
  0.0.0.0 space 0:0:0:0:0:0:0:0
  0.0.0.0
- 0:0:0:0:0:0:0:0 0.0.0.0' | cmp - $RSYSLOG_OUT_LOG
-if [ ! $? -eq 0 ]; then
-  echo "invalid response generated, $RSYSLOG_OUT_LOG is:"
-  cat $RSYSLOG_OUT_LOG
-  error_exit  1
-fi;
-
+ 0:0:0:0:0:0:0:0 0.0.0.0'
+cmp_exact
 exit_test
