@@ -1,8 +1,8 @@
 #!/bin/bash 
 # This file is part of the rsyslog project, released under ASL 2.0 
 . ${srcdir:=.}/diag.sh init
-# we libmaxmindb, in packaged versions, has a small cosmetic memory leak,
-# thus we need a supressions file:
+# we libmaxminddb, in packaged versions, has a small cosmetic memory leak,
+# thus we need a suppressions file:
 export RS_TESTBENCH_VALGRIND_EXTRA_OPTS="$RS_TESTBENCH_VALGRIND_EXTRA_OPTS --suppressions=$srcdir/libmaxmindb.supp"
 generate_conf
 add_conf '
@@ -11,7 +11,7 @@ template(name="outfmt" type="string" string="%$!iplocation%\n")
 module(load="../plugins/mmdblookup/.libs/mmdblookup")
 module(load="../plugins/mmnormalize/.libs/mmnormalize")
 module(load="../plugins/imptcp/.libs/imptcp")
-input(type="imptcp" port="'$TCPFLOOD_PORT'" ruleset="testing")
+input(type="imptcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port" ruleset="testing")
 
 ruleset(name="testing") {
 	action(type="mmnormalize" rulebase="'$srcdir'/mmdb.rb")
