@@ -5,7 +5,7 @@ generate_conf
 add_conf '
 module(load="../plugins/imtcp/.libs/imtcp")
 module(load="../contrib/mmtaghostname/.libs/mmtaghostname")
-input(type="imtcp" port="'$TCPFLOOD_PORT'" ruleset="ruleset")
+input(type="imtcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port" ruleset="ruleset")
 template(name="test" type="string" string="tag: %syslogtag%, server: %hostname%, msg: %msg%\n")
 ruleset(name="ruleset") {
 	action(type="mmtaghostname" tag="source-imtcp")
