@@ -5,8 +5,7 @@
 . ${srcdir:=.}/diag.sh init
 export NUMMESSAGES=50000
 
-port="$(get_free_port)"
-omhttp_start_server $port
+omhttp_start_server 0
 
 generate_conf
 add_conf '
@@ -26,7 +25,7 @@ if $msg contains "msgnum:" then
 		template="tpl"
 
 		server="localhost"
-		serverport="'$port'"
+		serverport="'$omhttp_server_lstnport'"
 		restpath="my/endpoint"
 		batch="on"
 		batch.format="jsonarray"
@@ -40,7 +39,7 @@ startup
 injectmsg
 shutdown_when_empty
 wait_shutdown
-omhttp_get_data $port my/endpoint jsonarray
+omhttp_get_data $omhttp_server_lstnport my/endpoint jsonarray
 omhttp_stop_server
 seq_check
 exit_test
