@@ -2,7 +2,7 @@
 # added 2015-05-22 by singh.janmejay
 # This file is part of the rsyslog project, released under ASL 2.0
 echo ===============================================================================
-echo \[stop_when_array_has_element.sh\]: loop detecting presense of an element and stopping ruleset execution
+echo \[stop_when_array_has_element.sh\]: loop detecting presence of an element and stopping ruleset execution
 . ${srcdir:=.}/diag.sh init stop_when_array_has_element.sh
 generate_conf
 add_conf '
@@ -10,7 +10,7 @@ template(name="foo" type="string" string="%$!foo%\n")
 
 module(load="../plugins/mmjsonparse/.libs/mmjsonparse")
 module(load="../plugins/imtcp/.libs/imtcp")
-input(type="imtcp" port="'$TCPFLOOD_PORT'")
+input(type="imtcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port")
 
 action(type="mmjsonparse")
 
