@@ -13,7 +13,8 @@ export QUEUE_EMPTY_CHECK_FUNC=wait_file_lines
 generate_conf
 add_conf '
 module(load="../plugins/imtcp/.libs/imtcp")
-input(type="imtcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port")
+input(type="imtcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port"
+	workerthreads="1") # single worker to ensure proer timing for this test
 $RepeatedMsgReduction on
 
 $template outfmt,"%msg:F,58:2%\n"
