@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+# call this via "python[3] script name"
 
 """A skeleton for a python rsyslog message modification plugin
    Copyright (C) 2014 by Adiscon GmbH
@@ -12,7 +12,7 @@
          http://www.apache.org/licenses/LICENSE-2.0
          -or-
          see COPYING.ASL20 in the source distribution
- 
+
    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -47,8 +47,7 @@ def onReceive(msg):
 	   reply before the next message is pushed to this module).
 	"""
 	data = json.loads(msg)
-        print json.dumps({"$!": {"sometag": "somevalue"}})
-#	print json.dumps({'msg': msg + "-modified"})
+	print(json.dumps({"$!": {"sometag": "somevalue"}}))
 
 def onExit():
 	""" Do everything that is needed to finish processing (e.g.
