@@ -264,6 +264,7 @@ queryLocalHostname(rsconf_t *const pConf)
 	uchar *LocalFQDNName;
 	DEFiRet;
 
+	assert(net.getLocalHostname != NULL); /* keep clang static analyzer silent - this IS the case */
 	CHKiRet(net.getLocalHostname(pConf, &LocalFQDNName));
 	uchar *dot = (uchar*) strstr((char*)LocalFQDNName, ".");
 	if(dot == NULL) {
@@ -294,7 +295,7 @@ writePidFile(void)
 	FILE *fp;
 	DEFiRet;
 
-	const char *tmpPidFile;
+	const char *tmpPidFile = NULL;
 
 	if(!strcmp(PidFile, NO_PIDFILE)) {
 		FINALIZE;
@@ -304,6 +305,7 @@ writePidFile(void)
 	}
 	if(tmpPidFile == NULL)
 		tmpPidFile = PidFile;
+
 	DBGPRINTF("rsyslogd: writing pidfile '%s'.\n", tmpPidFile);
 	if((fp = fopen((char*) tmpPidFile, "w")) == NULL) {
 		perror("rsyslogd: error writing pid file (creation stage)\n");
@@ -317,9 +319,12 @@ writePidFile(void)
 		if(rename(tmpPidFile, PidFile) != 0) {
 			perror("rsyslogd: error writing pid file (rename stage)");
 		}
+	}
+
+finalize_it:
+	if(tmpPidFile != PidFile) {
 		free((void*)tmpPidFile);
 	}
-finalize_it:
 	RETiRet;
 }
 
@@ -1190,6 +1195,7 @@ submitMsg2(smsg_t *pMsg)
 	}
 
 	pRuleset = MsgGetRuleset(pMsg);
+	assert(ruleset.GetRulesetQueue != NULL); /* This is only to keep clang static analyzer happy */
 	pQueue = (pRuleset == NULL) ? runConf->pMsgQueue : ruleset.GetRulesetQueue(pRuleset);
 
 	/* if a plugin logs a message during shutdown, the queue may no longer exist */
@@ -1960,7 +1966,7 @@ doHUP(void)
 	char buf[512];
 
 	DBGPRINTF("doHUP: doing modules\n");
-	if(ourConf->globals.bLogStatusMsgs) {
+	if(ourConf != NULL && ourConf->globals.bLogStatusMsgs) {
 		snprintf(buf, sizeof(buf),
 			 "[origin software=\"rsyslogd\" " "swVersion=\"" VERSION
 			 "\" x-pid=\"%d\" x-info=\"https://www.rsyslog.com\"] rsyslogd was HUPed",
@@ -2155,6 +2161,7 @@ mainloop(void)
 	sigaddset(&sigblockset, SIGHUP);
 
 	do {
+		sigemptyset(&origmask);
 		pthread_sigmask(SIG_BLOCK, &sigblockset, &origmask);
 		pthread_mutex_lock(&mutChildDied);
 		need_free_mutex = 1;
@@ -2192,6 +2199,7 @@ mainloop(void)
 
 		janitorRun();
 
+		assert(datetime.GetTime != NULL); /* This is only to keep clang static analyzer happy */
 		datetime.GetTime(&tTime);
 		checkGoneAwaySenders(tTime);
 
